# coding:utf8
import ast
import os
import re
import subprocess
import sys
import threading
import time


from syncplay import constants, utils
from syncplay.players.basePlayer import BasePlayer
from syncplay.messages import getMessage
from syncplay.utils import isMacOS, isWindows


class MplayerPlayer(BasePlayer):
    speedSupported = True
    customOpenDialog = False
    alertOSDSupported = False
    chatOSDSupported = False
    osdMessageSeparator = "; "

    RE_ANSWER = re.compile(constants.MPLAYER_ANSWER_REGEX)
    POSITION_QUERY = 'time_pos'
    OSD_QUERY = 'osd_show_text'

    def __init__(self, client, playerPath, filePath, args):
        from twisted.internet import reactor
        self.reactor = reactor
        self._client = client
        self._paused = None
        self._position = 0.0
        self._duration = None
        self._filename = None
        self._filepath = None
        self.quitReason = None
        self.lastLoadedTime = None
        self.fileLoaded = False
        self.delayedFilePath = None
        try:
            self._listener = self.__Listener(self, playerPath, filePath, args)
        except ValueError:
            self._client.ui.showMessage(getMessage("mplayer-file-required-notification"))
            self._client.ui.showMessage(getMessage("mplayer-file-required-notification/example"))
            self.drop()
            return
        self._listener.setDaemon(True)
        self._listener.start()

        self._durationAsk = threading.Event()
        self._filenameAsk = threading.Event()
        self._pathAsk = threading.Event()

        self._positionAsk = threading.Event()
        self._pausedAsk = threading.Event()

        self._preparePlayer()

    def _fileUpdateClearEvents(self):
        self._durationAsk.clear()
        self._filenameAsk.clear()
        self._pathAsk.clear()

    def _fileUpdateWaitEvents(self):
        self._durationAsk.wait()
        self._filenameAsk.wait()
        self._pathAsk.wait()

    def _onFileUpdate(self):
        self._fileUpdateClearEvents()
        self._getFilename()
        self._getLength()
        self._getFilepath()
        self._fileUpdateWaitEvents()
        self._client.updateFile(self._filename, self._duration, self._filepath)

    def _preparePlayer(self):
        self.setPaused(True)
        self.reactor.callLater(0, self._client.initPlayer, self)
        self._onFileUpdate()

    def askForStatus(self):
        self._positionAsk.clear()
        self._pausedAsk.clear()
        self._getPaused()
        self._getPosition()
        self._positionAsk.wait()
        self._pausedAsk.wait()
        self._client.updatePlayerStatus(self._paused, self._position)

    def _setProperty(self, property_, value):
        self._listener.sendLine("set_property {} {}".format(property_, value))

    def _getProperty(self, property_):
        self._listener.sendLine("get_property {}".format(property_))

    def displayMessage(
        self, message,
        duration=(constants.OSD_DURATION * 1000), OSDType=constants.OSD_NOTIFICATION, mood=constants.MESSAGE_NEUTRAL
    ):
        messageString = self._sanitizeText(message.replace("\\n", "<NEWLINE>")).replace("<NEWLINE>", "\\n")
        self._listener.sendLine('{} "{!s}" {} {}'.format(
            self.OSD_QUERY, messageString, duration, constants.MPLAYER_OSD_LEVEL))

    def displayChatMessage(self, username, message):
        messageString = "<{}> {}".format(username, message)
        messageString = self._sanitizeText(messageString.replace("\\n", "<NEWLINE>")).replace("<NEWLINE>", "\\n")
        duration = int(constants.OSD_DURATION * 1000)
        self._listener.sendLine('{} "{!s}" {} {}'.format(
            self.OSD_QUERY, messageString, duration, constants.MPLAYER_OSD_LEVEL))

    def setSpeed(self, value):
        self._setProperty('speed', "{:.2f}".format(value))

    def _loadFile(self, filePath):
        self._listener.sendLine('loadfile {}'.format(self._quoteArg(filePath)))

    def openFile(self, filePath, resetPosition=False):
        self._filepath = filePath
        self._loadFile(filePath)
        self._onFileUpdate()
        if self._paused != self._client.getGlobalPaused():
            self.setPaused(self._client.getGlobalPaused())
        self.setPosition(self._client.getGlobalPosition())

    def setFeatures(self, featureList):
        pass

    def setPosition(self, value):
        self._position = max(value, 0)
        self._setProperty(self.POSITION_QUERY, "{}".format(value))
        time.sleep(0.03)

    def setPaused(self, value):
        if self._paused != value:
            self._paused = not self._paused
            self._listener.sendLine('pause')

    def _getFilename(self):
        self._getProperty('filename')

    def _getLength(self):
        self._getProperty('length')

    def _getFilepath(self):
        self._getProperty('path')

    def _getPaused(self):
        self._getProperty('pause')

    def _getPosition(self):
        self._getProperty(self.POSITION_QUERY)

    def _sanitizeText(self, text):
        text = text.replace("\r", "")
        text = text.replace("\n", "")
        text = text.replace("\\\"", "<SYNCPLAY_QUOTE>")
        text = text.replace("\"", "<SYNCPLAY_QUOTE>")
        text = text.replace("%", "%%")
        text = text.replace("\\", "\\\\")
        text = text.replace("{", "\\\\{")
        text = text.replace("}", "\\\\}")
        text = text.replace("<SYNCPLAY_QUOTE>", "\\\"")
        return text

    def _quoteArg(self, arg):
        arg = arg.replace('\\', '\\\\')
        arg = arg.replace("'", "\\'")
        arg = arg.replace('"', '\\"')
        arg = arg.replace("\r", "")
        arg = arg.replace("\n", "")
        return '"{}"'.format(arg)

    def _fileIsLoaded(self):
        return True

    def _handleUnknownLine(self, line):
        pass

    def _storePosition(self, value):
        self._position = max(value, 0)

    def _storePauseState(self, value):
        self._paused = value

    def lineReceived(self, line):
        if line:
            self._client.ui.showDebugMessage("player << {}".format(line))
            line = line.replace("[cplayer] ", "")  # -v workaround
            line = line.replace("[term-msg] ", "")  # -v workaround
            line = line.replace("   cplayer: ", "")  # --msg-module workaround
            line = line.replace("  term-msg: ", "")
        if (
            "Failed to get value of property" in line or
            "=(unavailable)" in line or
            line == "ANS_filename=" or
            line == "ANS_length=" or
            line == "ANS_path="
        ):
            if "filename" in line:
                self._getFilename()
            elif "length" in line:
                self._getLength()
            elif "path" in line:
                self._getFilepath()
            return
        match = self.RE_ANSWER.match(line)
        if not match:
            self._handleUnknownLine(line)
            return

        name, value = [m for m in match.groups() if m]
        name = name.lower()

        if name == self.POSITION_QUERY:
            self._storePosition(float(value))
            self._positionAsk.set()
        elif name == "pause":
            self._storePauseState(bool(value == 'yes'))
            self._pausedAsk.set()
        elif name == "length":
            try:
                self._duration = float(value)
            except:
                self._duration = 0
            self._durationAsk.set()
        elif name == "path":
            self._filepath = value
            self._pathAsk.set()
        elif name == "filename":
            self._filename = value
            self._filenameAsk.set()
        elif name == "exiting":
            if value != 'Quit':
                if self.quitReason is None:
                    self.quitReason = getMessage("media-player-error").format(value)
                self.reactor.callFromThread(self._client.ui.showErrorMessage, self.quitReason, True)
            self.drop()

    @staticmethod
    def run(client, playerPath, filePath, args):
        mplayer = MplayerPlayer(client, MplayerPlayer.getExpandedPath(playerPath), filePath, args)
        return mplayer

    @staticmethod
    def getDefaultPlayerPathsList():
        l = []
        for path in constants.MPLAYER_PATHS:
            p = MplayerPlayer.getExpandedPath(path)
            if p:
                l.append(p)
        return l

    @staticmethod
    def getIconPath(path):
        return constants.MPLAYER_ICONPATH

    @staticmethod
    def getStartupArgs(path, userArgs):
        args = []
        if userArgs:
            args.extend(userArgs)
        args.extend(constants.MPLAYER_SLAVE_ARGS)
        return args

    @staticmethod
    def isValidPlayerPath(path):
        if "mplayer" in path and MplayerPlayer.getExpandedPath(path) and "mplayerc.exe" not in path and "smplayer.exe" not in path:  # "mplayerc.exe" is Media Player Classic (not Home Cinema) and smplayer.exe is SMPlayer:
            return True
        return False

    @staticmethod
    def getPlayerPathErrors(playerPath, filePath):
        if not filePath:
            return getMessage("no-file-path-config-error")

    @staticmethod
    def getExpandedPath(playerPath):
        if not os.path.isfile(playerPath):
            if os.path.isfile(playerPath + "mplayer.exe"):
                playerPath += "mplayer.exe"
                return playerPath
            elif os.path.isfile(playerPath + "\\mplayer.exe"):
                playerPath += "\\mplayer.exe"
                return playerPath
        if os.access(playerPath, os.X_OK):
            return playerPath
        for path in os.environ['PATH'].split(':'):
            path = os.path.join(os.path.realpath(path), playerPath)
            if os.access(path, os.X_OK):
                return path

    def notMplayer2(self):
        self.reactor.callFromThread(self._client.ui.showErrorMessage, getMessage("mplayer2-required"), True)
        self.drop()

    def _takeLocksDown(self):
        self._durationAsk.set()
        self._filenameAsk.set()
        self._pathAsk.set()
        self._positionAsk.set()
        self._pausedAsk.set()

    def drop(self):
        self._listener.sendLine('quit')
        self._takeLocksDown()
        self.reactor.callFromThread(self._client.stop, False)

    class __Listener(threading.Thread):
        def __init__(self, playerController, playerPath, filePath, args):
            self.sendQueue = []
            self.readyToSend = True
            self.lastSendTime = None
            self.lastNotReadyTime = None
            self.__playerController = playerController
            if not self.__playerController._client._config["chatOutputEnabled"]:
                self.__playerController.alertOSDSupported = False
                self.__playerController.chatOSDSupported = False
            if self.__playerController.getPlayerPathErrors(playerPath, filePath):
                raise ValueError()
            if filePath and '://' not in filePath:
                if not os.path.isfile(filePath) and 'PWD' in os.environ:
                    filePath = os.environ['PWD'] + os.path.sep + filePath
                filePath = os.path.realpath(filePath)

            call = [playerPath]
            if filePath:
                if isWindows() and not utils.isASCII(filePath):
                    self.__playerController.delayedFilePath = filePath
                    filePath = None
                else:
                    call.extend([filePath])
            call.extend(playerController.getStartupArgs(playerPath, args))
            # At least mpv may output escape sequences which result in syncplay
            # trying to parse something like
            # "\x1b[?1l\x1b>ANS_filename=blah.mkv". Work around this by
            # unsetting TERM.
            env = os.environ.copy()
            if 'TERM' in env:
                del env['TERM']
            # On macOS, youtube-dl requires system python to run. Set the environment
            # to allow that version of python to be executed in the mpv subprocess.
            if isMacOS():
                try:
                    pythonLibs = subprocess.check_output(['/usr/bin/python', '-E', '-c',
                                                          'import sys; print(sys.path)'],
                                                          text=True, env=dict())
                    pythonLibs = ast.literal_eval(pythonLibs)
                    pythonPath = ':'.join(pythonLibs[1:])
                except:
                    pythonPath = None
                if pythonPath is not None:
                    env['PATH'] = '/usr/bin:/usr/local/bin'
                    env['PYTHONPATH'] = pythonPath
            if filePath:
                self.__process = subprocess.Popen(
                    call, stdout=subprocess.PIPE, stdin=subprocess.PIPE, stderr=subprocess.STDOUT,
                    cwd=self.__getCwd(filePath, env), env=env, bufsize=0)
            else:
                self.__process = subprocess.Popen(
                    call, stdout=subprocess.PIPE, stdin=subprocess.PIPE, stderr=subprocess.STDOUT,
                    env=env, bufsize=0)
            threading.Thread.__init__(self, name="MPlayer Listener")

        def __getCwd(self, filePath, env):
            if not filePath:
                return None
            if os.path.isfile(filePath):
                cwd = os.path.dirname(filePath)
            elif 'HOME' in env:
                cwd = env['HOME']
            elif 'APPDATA' in env:
                cwd = env['APPDATA']
            else:
                cwd = None
            return cwd

        def run(self):
            line = self.__process.stdout.readline()
            line = line.decode('utf-8')
            if "MPlayer 1" in line:
                self.__playerController.notMplayer2()
            else:
                line = line.rstrip("\r\n")
                self.__playerController.lineReceived(line)
            while self.__process.poll() is None:
                line = self.__process.stdout.readline()
                line = line.decode('utf-8')
                line = line.rstrip("\r\n")
                self.__playerController.lineReceived(line)
            self.__playerController.drop()

        def sendChat(self, message):
            if message:
                if message[:1] == "/" and message != "/":
                    command = message[1:]
                    if command and command[:1] == "/":
                        message = message[1:]
                    else:
                        self.__playerController.reactor.callFromThread(
                            self.__playerController._client.ui.executeCommand, command)
                        return
                self.__playerController.reactor.callFromThread(self.__playerController._client.sendChat, message)

        def isReadyForSend(self):
            self.checkForReadinessOverride()
            return self.readyToSend

        def setReadyToSend(self, newReadyState):
            oldState = self.readyToSend
            self.readyToSend = newReadyState
            self.lastNotReadyTime = time.time() if newReadyState == False else None
            if self.readyToSend == True:
                self.__playerController._client.ui.showDebugMessage("<mpv> Ready to send: True")
            else:
                self.__playerController._client.ui.showDebugMessage("<mpv> Ready to send: False")
            if self.readyToSend == True and oldState == False:
                self.processSendQueue()

        def checkForReadinessOverride(self):
            if self.lastNotReadyTime and time.time() - self.lastNotReadyTime > constants.MPV_MAX_NEWFILE_COOLDOWN_TIME:
                self.setReadyToSend(True)

        def sendLine(self, line, notReadyAfterThis=None):
            self.checkForReadinessOverride()
            if self.readyToSend == False and "print_text ANS_pause" in line:
                self.__playerController._client.ui.showDebugMessage("<mpv> Not ready to get status update, so skipping")
                return
            try:
                if self.sendQueue:
                    if constants.MPV_SUPERSEDE_IF_DUPLICATE_COMMANDS:
                        for command in constants.MPV_SUPERSEDE_IF_DUPLICATE_COMMANDS:
                            if line.startswith(command):
                                for itemID, deletionCandidate in enumerate(self.sendQueue):
                                    if deletionCandidate.startswith(command):
                                        self.__playerController._client.ui.showDebugMessage(
                                            "<mpv> Remove duplicate (supersede): {}".format(self.sendQueue[itemID]))
                                        try:
                                            self.sendQueue.remove(self.sendQueue[itemID])
                                        except UnicodeWarning:
                                            self.__playerController._client.ui.showDebugMessage(
                                                "<mpv> Unicode mismatch occured when trying to remove duplicate")
                                            # TODO: Prevent this from being triggered
                                            pass
                                        break
                            break
                    if constants.MPV_REMOVE_BOTH_IF_DUPLICATE_COMMANDS:
                        for command in constants.MPV_REMOVE_BOTH_IF_DUPLICATE_COMMANDS:
                            if line == command:
                                for itemID, deletionCandidate in enumerate(self.sendQueue):
                                    if deletionCandidate == command:
                                        self.__playerController._client.ui.showDebugMessage(
                                            "<mpv> Remove duplicate (delete both): {}".format(self.sendQueue[itemID]))
                                        self.__playerController._client.ui.showDebugMessage(self.sendQueue[itemID])
                                        return
            except:
                self.__playerController._client.ui.showDebugMessage("<mpv> Problem removing duplicates, etc")
            self.sendQueue.append(line)
            self.processSendQueue()
            if notReadyAfterThis:
                self.setReadyToSend(False)

        def processSendQueue(self):
            while self.sendQueue and self.readyToSend:
                if self.lastSendTime and time.time() - self.lastSendTime < constants.MPV_SENDMESSAGE_COOLDOWN_TIME:
                    self.__playerController._client.ui.showDebugMessage(
                        "<mpv> Throttling message send, so sleeping for {}".format(
                            constants.MPV_SENDMESSAGE_COOLDOWN_TIME))
                    time.sleep(constants.MPV_SENDMESSAGE_COOLDOWN_TIME)
                try:
                    lineToSend = self.sendQueue.pop()
                    if lineToSend:
                        self.lastSendTime = time.time()
                        self.actuallySendLine(lineToSend)
                except IndexError:
                    pass

        def actuallySendLine(self, line):
            try:
                # if not isinstance(line, str):
                    # line = line.decode('utf8')
                line = line + "\n"
                self.__playerController._client.ui.showDebugMessage("player >> {}".format(line))
                line = line.encode('utf-8')
                self.__process.stdin.write(line)
            except IOError:
                pass



import os
from syncplay.utils import isWindowsConsole

if "QT_PREFERRED_BINDING" not in os.environ:
    os.environ["QT_PREFERRED_BINDING"] = os.pathsep.join(
        ["PySide6", "PySide2", "PySide", "PyQt5", "PyQt4"]
    )

if not isWindowsConsole():
    try:
        from syncplay.ui.gui import MainWindow as GraphicalUI
    except (ImportError, AttributeError) as e:
        pass
from syncplay.ui.consoleUI import ConsoleUI


def getUi(graphical=True, passedBar=None):
    if graphical and not isWindowsConsole():
        ui = GraphicalUI(passedBar=passedBar)
    else:
        ui = ConsoleUI()
        ui.setDaemon(True)
        ui.start()
    return ui



# coding:utf8

"""Turkish dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

tr = {
    "LANGUAGE": "Türkçe", # Turkish
    "LANGUAGE-TAG": "tr",

    # Strings for Windows NSIS installer
    "installer-language-file": "Turkish.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Syncplay'i ortam dosyalarıyla ilişkilendirin.",
    "installer-shortcut": "Aşağıdaki konumlarda kısayollar oluşturun:",
    "installer-start-menu": "Başlangıç menüsü",
    "installer-desktop": "Masaüstü",
    "installer-quick-launch-bar": "Hızlı Başlatma Çubuğu",
    "installer-automatic-updates": "Güncellemeleri otomatik denetle",
    "installer-uninstall-configuration": "Yapılandırma dosyasını silin.",

    # Client notifications
    "config-cleared-notification": "Ayarlar temizlendi. Geçerli bir konfigürasyon kaydettiğinizde değişiklikler kaydedilecektir.",

    "relative-config-notification": "Göreli yapılandırma dosya(ları) yüklendi: {}",

    "connection-attempt-notification": "{} İle bağlantı kurulmaya çalışılıyor: {}",  # Port, IP
    "reconnection-attempt-notification": "Sunucuyla bağlantı kesildi, yeniden bağlanılmaya çalışılıyor",
    "disconnection-notification": "Sunucuyla bağlantısı kesildi",
    "connection-failed-notification": "Sunucuyla bağlantı başarısız oldu",
    "connected-successful-notification": "Sunucuya başarıyla bağlandı",
    "retrying-notification": "% s,% d saniye içinde yeniden deneniyor ...",  # Seconds
    "reachout-successful-notification": "Başarıyla ulaşıldı {} ({})",

    "rewind-notification": "{} ile zaman farkı nedeniyle geri alındı",  # User
    "fastforward-notification": "{} ile zaman farkı nedeniyle ileri sarıldı",  # User
    "slowdown-notification": "{} ile zaman farkı nedeniyele nedeniyle yavaşlıyor",  # User
    "revert-notification": "Hızı normale döndürülüyor",

    "pause-notification": "{} duraklattı ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{} devam ettirdi",  # User
    "seek-notification": "{}, {} konumundan {} konumuna atladı",  # User, from time, to time

    "current-offset-notification": "Mevcut fark: {} saniye",  # Offset

    "media-directory-list-updated-notification": "Syncplay ortam dizinleri güncellendi.",

    "room-join-notification": "{} odaya katıldı: '{}'",  # User
    "left-notification": "{} ayrıldı",  # User
    "left-paused-notification": "{} ayrıldı, {} duraklattı",  # User who left, User who paused
    "playing-notification": "{} oynatıyor '{}' ({})",  # User, file, duration
    "playing-notification/room-addendum":  " odada: '{}'",  # Room

    "not-all-ready": "Hazır değil: {}",  # Usernames
    "all-users-ready": "Herkes hazır ({} kullanıcı)",  # Number of ready users
    "ready-to-unpause-notification": "Artık hazır olarak ayarlandınız - devam ettirmek için yeniden duraklatmayı kaldırın",
    "set-as-ready-notification": "Artık hazırsınız",
    "set-as-not-ready-notification": "Artık hazır değilsiniz",
    "autoplaying-notification": "{} içinde otomatik oynatılıyor ...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Oda operatörü '{}' parolası ile tanımlanıyor ...",
    "failed-to-identify-as-controller-notification": "{}, operatörü olarak tanımlanamadı.",
    "authenticated-as-controller-notification": "{}, oda operatörü olarak doğrulandı",
    "created-controlled-room-notification": "Yönetilen oda '{}' '{}' şifresiyle oluşturuldu. Lütfen bu bilgileri ileride başvurmak üzere kaydedin!\n\nYönetilen odalarda, oynatma listesini duraklatabilen, devam ettirebilen, arayabilen ve değiştirebilen tek kişi olan oda operatörleri ile herkes senkronize edilir.\n\nNormal izleyicilerden '{}' odasına katılmalarını istemelisiniz, ancak oda operatörleri kendilerini otomatik olarak doğrulamak için '{}' odasına katılabilir.",  # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "Oynadığınız dosya, {} dosyasından farklı görünüyor",  # User
    "file-differences-notification": "Dosyanız aşağıdaki şekil(ler)de farklılık gösterir: {}",  # Differences
    "room-file-differences": "Dosya farklılıkları: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "adı",
    "file-difference-filesize": "boyutu",
    "file-difference-duration": "süresi",
    "alone-in-the-room": "Odada yalnızsın",

    "different-filesize-notification": " (dosya boyutları sizinkinden farklı!)",
    "userlist-playing-notification": "{} oynuyor:",  # Username
    "file-played-by-notification": "Dosya: {} şu kullanıcı tarafından oynatılıyor:",  # File
    "no-file-played-notification": "{} dosya oynatmıyor",  # Username
    "notplaying-notification": "Herhangi bir dosya oynatmayan kişiler:",
    "userlist-room-notification":  "Odada '{}':",  # Room
    "userlist-file-notification": "Dosya",
    "controller-userlist-userflag": "Operatör",
    "ready-userlist-userflag": "Hazır",

    "update-check-failed-notification": "Syncplay {} 'in güncel olup olmadığı otomatik olarak kontrol edilemedi. Güncellemeleri manuel olarak kontrol etmek için https://syncplay.pl/ adresini ziyaret etmek ister misiniz?",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay güncel",
    "syncplay-updateavailable-notification": "Syncplay'in yeni bir sürümü mevcut. Sürüm sayfasını ziyaret etmek istiyor musunuz?",

    "mplayer-file-required-notification": "MPlayer kullanarak Syncplay, başlatırken dosya sağlamanızı gerektirir",
    "mplayer-file-required-notification/example": "Kullanım örneği: syncplay [options] [url|path/]filename",
    "mplayer2-required": "Syncplay, MPlayer 1.x ile uyumlu değil, lütfen mplayer2 veya mpv kullanın",

    "unrecognized-command-notification": "Tanımsız komut",
    "commandlist-notification": "Kullanılabilir komutlar:",
    "commandlist-notification/room": "\tr [name] - odayı değiştirir",
    "commandlist-notification/list": "\tl - kullanıcı listesini gösterir",
    "commandlist-notification/undo": "\tu - son isteği geri alır",
    "commandlist-notification/pause": "\tp - duraklatmayı değiştirir",
    "commandlist-notification/seek": "\t[s][+-]time - verilen zaman değerine atlar, eğer + veya - belirtilmezse, saniye:dakika cinsinden mutlak zamandır.",
    "commandlist-notification/offset": "\to[+-]süre - yerel oynatmayı sunucu arama konumundan verilen süreye göre (saniye veya dakika:saniye cinsinden) dengeleme - bu, kullanımdan kaldırılmış bir özelliktir",
    "commandlist-notification/help": "\th - yardım",
    "commandlist-notification/toggle": "\tt - izlemeye hazır olup olmadığınızı değiştirir",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [name] - mevcut odanın adını kullanarak yönetilen oda oluştur",
    "commandlist-notification/auth": "\ta [password] - operatör şifresi ile oda operatörü olarak kimlik doğrular",
    "commandlist-notification/chat": "\tch [message] - bir odaya sohbet mesajı gönderir",
    "commandList-notification/queue": "\tqa [file/url] - oynatma listesinin altına dosya veya bağlantı ekler",
    "commandList-notification/queueandselect": "\tqas [dosya/url] - oynatma listesinin en altına dosya veya URL ekler ve onu seçer",
    "commandList-notification/playlist": "\tql - mevcut oynatma listesini gösterir",
    "commandList-notification/select": "\tqs [index] - oynatma listesinde verilen girişi seçer",
    "commandList-notification/next": "\tqn - oynatma listesindeki sonraki girişi seçer",
    "commandList-notification/delete": "\tqd [index] - verilen girişi oynatma listesinden siler",
    "syncplay-version-notification": "Syncplay sürümü: {}",  # syncplay.version
    "more-info-notification": "Daha fazla bilgiye şu adresten ulaşabilirsiniz: {}",  # projectURL

    "gui-data-cleared-notification": "Syncplay, GUI tarafından kullanılan yolu ve pencere durumu verilerini temizledi.",
    "language-changed-msgbox-label": "Syncplay'i çalıştırdığınızda dil değiştirilecek.",
    "promptforupdate-label": "Syncplay'in zaman zaman güncellemeleri otomatik olarak kontrol etmesi uygun mudur?",

    "media-player-latency-warning": "Uyarı: Medya yürütücünün yanıt vermesi {} saniye sürdü. Senkronizasyon sorunları yaşıyorsanız, sistem kaynaklarını boşaltmak için uygulamaları kapatın ve bu işe yaramazsa, farklı bir medya oynatıcı deneyin.",  # Seconds to respond
    "mpv-unresponsive-error": "mpv {} saniye boyunca yanıt vermedi, bu nedenle arızalı görünüyor. Lütfen Syncplay'i yeniden başlatın.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Çıkmak için enter tuşuna basın\n",

    # Client errors
    "missing-arguments-error": "Bazı gerekli argümanlar eksik, bakınız --help",
    "server-timeout-error": "Sunucuyla bağlantı zaman aşımına uğradı",
    "mpc-slave-error": "Bağımlı modda MPC başlatılamıyor!",
    "mpc-version-insufficient-error": "MPC sürümü yeterli değil, lütfen `mpc-hc`> =` {} `kullanın",
    "mpc-be-version-insufficient-error": "MPC sürümü yeterli değil, lütfen `mpc-hc`> =` {} `kullanın",
    "mpv-version-error": "Syncplay, mpv'nin bu sürümüyle uyumlu değil. Lütfen farklı bir mpv sürümü kullanın (ör. Git HEAD).",
    "mpv-failed-advice": "Mpv'nin başlatılamamasının nedeni, desteklenmeyen komut satırı bağımsız değişkenlerinin veya mpv'nin desteklenmeyen bir sürümünün kullanılması olabilir.",
    "player-file-open-error": "Oynatıcı dosyayı açamadı",
    "player-path-error": "Oynatıcı yolu doğru ayarlanmadı. Desteklenen oynatıcılar şunlardır: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 ve IINA",
    "hostname-empty-error": "Ana bilgisayar adı boş olamaz",
    "empty-error": "{} boş olamaz",  # Configuration
    "media-player-error": "Medaya oynatıcısı hatası: \"{}\"",  # Error line
    "unable-import-gui-error": "GUI kitaplıkları içe aktarılamadı. GUI'nin çalışması için PySide'ın doğru sürümünün kurulu olması gerekir. Syncplay'i terminal modunda çalıştırmak istiyorsanız --no-gui komut satırı anahtarıyla çalıştırın. Daha fazla ayrıntı için https://syncplay.pl/guide/ adresine bakın.",
    "unable-import-twisted-error": "Twisted içe aktarılamadı. Lütfen Twisted v16.4.0 veya sonraki sürümünü yükleyin.",

    "arguments-missing-error": "Bazı gerekli argümanlar eksik, bakınız --help",

    "unable-to-start-client-error": "İstemci başlatılamıyor",

    "player-path-config-error": "Oynatıcı yolu doğru ayarlanmadı. Desteklenen oyuncular şunlardır: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 ve IINA.",
    "no-file-path-config-error": "Oynatıcınız başlatılmadan önce dosya seçilmelidir",
    "no-hostname-config-error": "Ana bilgisayar adı boş olamaz",
    "invalid-port-config-error": "Bağlantı noktası geçerli olmalıdır",
    "empty-value-config-error": "{} boş olamaz",  # Config option

    "not-json-error": "JSON ile kodlanmış bir dize değil\n",
    "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE
    "version-mismatch-error": "İstemci ve sunucu sürümleri arasında uyumsuzluk\n",
    "vlc-failed-connection": "VLC'ye bağlanılamadı. Syncplay.lua'yı yüklemediyseniz ve VLC'nin en son sürümünü kullanıyorsanız talimatlar için lütfen https://syncplay.pl/LUA/ adresine bakın. Syncplay ve VLC 4 şu anda uyumlu değildir, bu nedenle VLC 3'ü veya mpv gibi bir alternatifi kullanın.",
    "vlc-failed-noscript": "VLC, syncplay.lua arabirim komut dosyasının yüklenmediğini bildirdi. Talimatlar için lütfen https://syncplay.pl/LUA/ adresine bakın.",
    "vlc-failed-versioncheck": "VLC'nin bu sürümü Syncplay tarafından desteklenmemektedir.",
    "vlc-initial-warning": 'VLC, özellikle .mp4 ve .avi dosyaları için Syncplay\'e her zaman doğru konum bilgisi sağlamaz. Hatalı arama ile ilgili sorunlar yaşarsanız, lütfen <a href="https://mpv.io/"> mpv</a> gibi alternatif bir medya oynatıcı deneyin. (veya Windows kullanıcıları için <a href="https://github.com/stax76/mpv.net/">mpv.net</a>).',

    "feature-sharedPlaylists": "paylaşılan oynatma listeleri",  # used for not-supported-by-server-error
    "feature-chat": "sohbet",  # used for not-supported-by-server-error
    "feature-readiness": "hazırlık",  # used for not-supported-by-server-error
    "feature-managedRooms": "yönetilen odalar",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "{} özelliği bu sunucu tarafından desteklenmiyor ..",  # feature
    "shared-playlists-not-supported-by-server-error": "Paylaşılan çalma listeleri özelliği sunucu tarafından desteklenmeyebilir. Doğru çalıştığından emin olmak için Syncplay  {}+ çalıştıran bir sunucu gerektirir, ancak sunucu Syncplay {} çalıştırmaktadır.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "Paylaşılan çalma listesi özelliği, sunucu yapılandırmasında devre dışı bırakıldı. Bu özelliği kullanmak için farklı bir sunucuya bağlanmanız gerekecektir.",

    "invalid-seek-value": "Geçersiz atlama değerie",
    "invalid-offset-value": "Geçersiz zaman konumu değeri",

    "switch-file-not-found-error": "'{0}' dosyasına geçilemedi. Syncplay, belirtilen medya dizinlerine bakar.",  # File not found
    "folder-search-timeout-error": "'{}' üzerinden arama yapmak çok uzun sürdüğü için medya dizinlerinde medya araması durduruldu (after having processed the first {} files). Ortam klasörleri listenizde arama yapmak için çok fazla alt klasörün bulunduğu bir klasör seçerseniz bu meydana gelir. Otomatik dosya değiştirmenin tekrar çalışması için lütfen menü çubuğunda Dosya-> Medya Dizinlerini Ayarla'yı seçin ve bu dizini kaldırın veya uygun bir alt klasörle değiştirin. Klasör gerçekten iyi durumdaysa, Dosya-> Medya Dizinlerini Ayarla'yı seçip 'Tamam'a basarak yeniden etkinleştirebilirsiniz.",  # Folder, Files processed - TODO: Update translation (refer back to original English text)
    "folder-search-timeout-warning": "Warning: It has taken {} second(s) to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "Dizine erişim çok uzun sürdüğü için '{}' içindeki medya araması durduruldu. Bu, bir ağ sürücüsü ise veya sürücünüzü bir süre kullanılmadığında dönecek şekilde yapılandırırsanız olabilir. Otomatik dosya değiştirmenin tekrar çalışması için lütfen Dosya-> Medya Dizinlerini Ayarla'ya gidin ve dizini kaldırın veya sorunu çözün (örn. Güç tasarrufu ayarlarını değiştirerek).",  # Folder
    "added-file-not-in-media-directory-error": "Bilinen bir medya dizini olmayan '{}' içine bir dosya yüklediniz. Menü çubuğunda Dosya-> Medya Dizinlerini Ayarla'yı seçerek bunu bir medya dizini olarak ekleyebilirsiniz.",  # Folder
    "no-media-directories-error": "Hiçbir medya dizini ayarlanmadı. Paylaşılan çalma listesi ve dosya değiştirme özelliklerinin düzgün çalışması için lütfen Dosya-> Ortam Dizinlerini Ayarla'yı seçin ve Syncplay'in medya dosyalarını bulmak için nereye bakması gerektiğini belirtin.",
    "cannot-find-directory-error": "'{}' medya dizini bulunamadı. Medya dizinleri listenizi güncellemek için lütfen menü çubuğundan Dosya-> Medya Dizinlerini Ayarla'yı seçin ve Syncplay'in medya dosyalarını bulmak için nereye bakması gerektiğini belirtin.",

    "failed-to-load-server-list-error": "Genel sunucu listesi yüklenemedi. Lütfen tarayıcınızda https://www.syncplay.pl/ adresini ziyaret edin.",

    # Client arguments
    "argument-description": 'Ağ üzerinden birden çok medya oynatıcı örneğinin oynatılmasını senkronize etme çözümü.',
    "argument-epilog": 'Sağlanan seçenek yoksa _config değerleri kullanılacaktır',
    "nogui-argument": 'GUI olmadan göster',
    "host-argument": 'sunucunun adresi',
    "name-argument": 'istenilen kullanıcı adı',
    "debug-argument": 'debug modu',
    "force-gui-prompt-argument": 'yapılandırma isteminin görünmesini sağlayın',
    "no-store-argument": 'değerleri .syncplay içinde saklamayın',
    "room-argument": 'varsayılan oda',
    "password-argument": 'sunucu parolası',
    "player-path-argument": 'oynatıcınızın çalıştırılabilir yolu',
    "file-argument": 'oynatmak için dosya',
    "args-argument": 'oynatıcı seçenekleri, ile başlayan seçenekleri iletmeniz gerekiyorsa - bunların başına tek \'--\' argümanı ekleyin',
    "clear-gui-data-argument": 'QSettings olarak depolanan yol ve pencere durumu GUI verilerini sıfırlar',
    "language-argument": 'Syncplay mesajları için dil ({})', # Languages

    "version-argument": 'versiyonunuzu yazdırır',
    "version-message": "Syncplay sürümünü kullanıyorsunuz {} ({})",

    "load-playlist-from-file-argument": "metin dosyasından oynatma listesi yükler (her satıra bir giriş)",


    # Client labels
    "config-window-title": "Syncplay yapılandırması",

    "connection-group-title": "Bağlantı ayarları",
    "host-label": "Sunucu adresi: ",
    "name-label":  "Kullanıcı adı (isteğe bağlı):",
    "password-label":  "Sunucu şifresi (varsa):",
    "room-label": "Varsayılan oda: ",
    "roomlist-msgbox-label": "Oda listesini düzenleyin (her satıra bir tane)",

    "media-setting-title": "Medya oynatıcı ayarları",
    "executable-path-label": "Medya oynatıcı dosya yolu:",
    "media-path-label": "Video dosya yolu (isteğe bağlı):",
    "player-arguments-label": "Oynatıcı argümanları (varsa):",
    "browse-label": "Araştır",
    "update-server-list-label": "Listeyi güncelle",

    "more-title": "Daha fazla ayar göster",
    "never-rewind-value": "Asla",
    "seconds-suffix": " secs",
    "privacy-sendraw-option": "raw gönder",
    "privacy-sendhashed-option": "hashed gönder",
    "privacy-dontsend-option": "Gönderme",
    "filename-privacy-label": "Dosya yolu bilgisi:",
    "filesize-privacy-label": "Dosya boyutu bilgisi:",
    "checkforupdatesautomatically-label": "Syncplay güncellemelerini otomatik olarak kontrol edin",
    "autosavejoinstolist-label": "Katıldığınız odaları oda listesine ekleyin",
    "slowondesync-label": "Küçük desenkronizasyonda yavaşlama (MPC-HC / BE'de desteklenmez)",
    "rewindondesync-label": "Ana desenkronizasyonda geri sar (önerilir)",
    "fastforwardondesync-label": "Geride kalırsa hızlı ileri sar (önerilir)",
    "dontslowdownwithme-label": "Başkalarını asla yavaşlatma veya geri sarma (deneysel)",
    "pausing-title": "Duraklatılıyor",
    "pauseonleave-label": "Kullanıcı ayrıldığında duraklayın (ör. Bağlantısı kesilirse)",
    "readiness-title": "İlk hazırlık durumu",
    "readyatstart-label": "Beni varsayılan olarak 'izlemeye hazır' olarak ayarla",
    "forceguiprompt-label": "Syncplay yapılandırma penceresini her zaman gösterme",  # (Inverted)
    "showosd-label": "OSD Mesajlarını Etkinleştir",

    "showosdwarnings-label": "Uyarıları dahil edin (ör. Dosyalar farklı olduğunda, kullanıcılar hazır olmadığında)",
    "showsameroomosd-label": "Odanızdaki etkinlikleri dahil edin",
    "shownoncontrollerosd-label": "Operatör olmayanlardan gelen olayları yönetilen odalara dahil et",
    "showdifferentroomosd-label": "Diğer odalardaki etkinlikleri dahil et",
    "showslowdownosd-label": "Yavaşlatma / geri alma bildirimlerini dahil et",
    "language-label": "Dil:",
    "automatic-language": "Varsayılan ({})",  # Default language
    "showdurationnotification-label": "Medya süresi uyuşmazlıkları konusunda uyarın",
    "basics-label": "Temeller",
    "readiness-label": "Oynat/Duraklat",
    "misc-label": "Misc",
    "core-behaviour-title": "Çekirdek oda davranışı",
    "syncplay-internals-title": "Syncplay dahili bileşenleri",
    "syncplay-mediasearchdirectories-title": "Medya aramak için dizinler",
    "syncplay-mediasearchdirectories-label": "Medya aramak için dizinler (satır başına bir yol)",
    "sync-label": "Sync",
    "sync-otherslagging-title": "Başkaları geride kalıyorsa ...",
    "sync-youlaggging-title": "Geride kalıyorsan ...",
    "messages-label": "mesajlar",
    "messages-osd-title": "Ekran üstü görüntü ayarları",
    "messages-other-title": "Diğer ekran ayarları",
    "chat-label": "Sohbet",
    "privacy-label": "Gizlilik",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Gizlilik ayarları",
    "unpause-title": "Oynat'a basarsanız, hazır olarak ayarlayın ve:",
    "unpause-ifalreadyready-option": "Zaten hazır olarak ayarlanmışsa duraklatmayı bırakın",
    "unpause-ifothersready-option": "Zaten hazırsa veya odadaki diğerleri hazırsa duraklatmayı bırakın (varsayılan)",
    "unpause-ifminusersready-option": "Zaten hazırsa veya diğerleri hazırsa ve min kullanıcılar hazırsa duraklatmayı kaldırın",
    "unpause-always": "Her zaman devam ettir",
    "syncplay-trusteddomains-title": "Güvenilir alanlar (akış hizmetleri ve barındırılan içerik için)",

    "chat-title": "Sohbet mesajı girişi",
    "chatinputenabled-label": "Mpv aracılığıyla sohbet girişini etkinleştir",
    "chatdirectinput-label": "Anında sohbet girişine izin ver (sohbet etmek için enter tuşuna basma zorunluluğunu atlayın)",
    "chatinputfont-label": "Sohbet yazı tipi",
    "chatfont-label": "Yazı tipini ayarla",
    "chatcolour-label": "Rengi ayarla",
    "chatinputposition-label": "Mesaj giriş alanının mpv'deki konumu",
    "chat-top-option": "Üst",
    "chat-middle-option": "Orta",
    "chat-bottom-option": "Alt",
    "chatoutputheader-label": "Sohbet mesajı çıkışı",
    "chatoutputfont-label": "Sohbet çıktı yazı tipi",
    "chatoutputenabled-label": "Medya oynatıcıda sohbet çıkışını etkinleştirin (şimdilik yalnızca mpv)",
    "chatoutputposition-label": "Çıkış modu",
    "chat-chatroom-option": "Sohbet odası stili",
    "chat-scrolling-option": "Kaydırma stili",

    "mpv-key-tab-hint": "Alfabe satırı tuşu kısayollarına erişimi değiştirmek için [TAB].",
    "mpv-key-hint": "Mesaj göndermek için [ENTER]. Sohbet modundan çıkmak için [ESC].",
    "alphakey-mode-warning-first-line": "Geçici olarak eski mpv bağlamalarını a-z tuşlarıyla kullanabilirsiniz.",
    "alphakey-mode-warning-second-line": "Syncplay sohbet moduna dönmek için [TAB] tuşuna basın.",

    "help-label": "Yardım",
    "reset-label": "Varsayılanları geri yükle",
    "run-label": "Syncplay'i çalıştırın",
    "storeandrun-label": "Yapılandırmayı depolayın ve Syncplay'i çalıştırın",

    "contact-label": "E-posta <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a> göndermekten çekinmeyin, GitHub üzerinden <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>sorun bildirebilir</nobr></a> / <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> to make a suggestion or ask a question via GitHub, Facebook üzerinden <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>bizi beğenebilir</nobr></a>, Twitter üzerinden <a href=\"https://twitter.com/Syncplay/\"><nobr>bizi takip edebilir</nobr></a>, veya <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a> adresinden sayfamızı ziyaret edebilirsiniz. Hassas bilgileri göndermek için Syncplay kullanmayın.", # TODO: Update translation

    "joinroom-label": "Odaya katıl",
    "joinroom-menu-label": "{} odasına katıl",
    "seektime-menu-label": "Zamana atla",
    "undoseek-menu-label": "Atlamayı geri al",
    "play-menu-label": "Oynat",
    "pause-menu-label": "Duraklat",
    "playbackbuttons-menu-label": "Oynatma düğmelerini göster",
    "autoplay-menu-label": "Otomatik oynat düğmesini göster",
    "autoplay-guipushbuttonlabel": "Her şey hazır olduğunda oynat",
    "autoplay-minimum-label": "Asgari kullanıcı:",
    "hideemptyrooms-menu-label": "Boş kalıcı odaları gizle",

    "sendmessage-label": "Gönder",

    "ready-guipushbuttonlabel": "İzlemeye hazırım!",

    "roomuser-heading-label": "Oda / Kullanıcı",
    "size-heading-label": "Boyut",
    "duration-heading-label": "Uzunluk",
    "filename-heading-label": "Dosya Adı",
    "notifications-heading-label": "Bildirimler",
    "userlist-heading-label": "Kimin ne oynadığını listesi",

    "browseformedia-label": "Medya dosyalarına göz atın",

    "file-menu-label": "&Dosya",  # & precedes shortcut key
    "openmedia-menu-label": "Medya d&osyasını aç",
    "openstreamurl-menu-label": "Medya akışı &URL'sini aç",
    "setmediadirectories-menu-label": "Medya di&zinlerini ayarlayın",
    "loadplaylistfromfile-menu-label": "Dosyadan oynatma &listesi yükle",
    "saveplaylisttofile-menu-label": "Oynatma listesini dosyaya kay&dedin",
    "exit-menu-label": "Çı&kış",
    "advanced-menu-label": "&Gelişmiş",
    "window-menu-label": "&Pencere",
    "setoffset-menu-label": "Zaman &konumunu ayarla",
    "createcontrolledroom-menu-label": "&Yönetilen oda oluştur",
    "identifyascontroller-menu-label": "&Oda operatörü olarak tanımlayın",
    "settrusteddomains-menu-label": "Güvenilir &domain ayarlayın",
    "addtrusteddomain-menu-label": "{} Alanını güvenilen alan olarak ekleyin",  # Domain

    "edit-menu-label": "Düzenl&e",
    "cut-menu-label": "Ke&s",
    "copy-menu-label": "&Kopyala",
    "paste-menu-label": "&Yapıştır",
    "selectall-menu-label": "&Tümünü Seç",

    "playback-menu-label": "&Oynatma",

    "help-menu-label": "&Yardım",
    "userguide-menu-label": "&Kullanım kılavuzunu aç",
    "update-menu-label": "&Güncellemeleri kontrol ediniz",

    "startTLS-initiated": "Güvenli bağlantı kurulmaya çalışılıyor",
    "startTLS-secure-connection-ok": "Güvenli bağlantı kuruldu ({})",
    "startTLS-server-certificate-invalid": 'Güvenli bağlantı kurulamadı. Sunucu geçersiz bir güvenlik sertifikası kullanıyor. Bu iletişim üçüncü bir şahıs tarafından engellenebilir. Daha fazla ayrıntı ve sorun giderme için <a href="https://syncplay.pl/trouble"> buraya </a> bakın.',
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay, ana bilgisayar adı için geçerli olmayan bir sertifika kullandığından bu sunucuya güvenmiyor.",
    "startTLS-not-supported-client": "Bu istemci TLS'yi desteklemiyor",
    "startTLS-not-supported-server": "Bu sunucu TLS'yi desteklemiyor",

    # TLS certificate dialog
    "tls-information-title": "Sertifika Ayrıntıları",
    "tls-dialog-status-label": "<strong> Syncplay, {} ile şifrelenmiş bir bağlantı kullanıyor. </strong>",
    "tls-dialog-desc-label": "Dijital sertifika yapılam şifreleme, <br>bu sunucuya {} veri gönderirken ve alırken bilgileri gizli tutar.",
    "tls-dialog-connection-label": "Transport Layer Security (TLS), sürüm {} ile şifrelenen şifre<br/>paketi: {}.",
    "tls-dialog-certificate-label": "{} Tarafından verilen sertifika {} tarihine kadar geçerlidir.",

    # About dialog
    "about-menu-label": "&Syncplay hakkında",
    "about-dialog-title": "Syncplay hakkında",
    "about-dialog-release": "Sürüm {} yayın {}",
    "about-dialog-license-text": "Apache Lisansı altında&nbsp;Lisanslanmıştır,&nbsp;Sürüm 2.0",
    "about-dialog-license-button": "Lisans",
    "about-dialog-dependencies": "Bağımlılıklar",

    "setoffset-msgbox-label": "Zaman konumunu ayarla",
    "offsetinfo-msgbox-label": "Zaman Konumu (Kullanım talimatları için https://syncplay.pl/guide/ adresine bakın):",

    "promptforstreamurl-msgbox-label": "Medya akışı URL'sini aç",
    "promptforstreamurlinfo-msgbox-label": "Akış URL'si",

    "addfolder-label": "Klasör ekle",

    "adduris-msgbox-label": "Oynatma listesine URL ekleyin (her satıra bir tane)",
    "editplaylist-msgbox-label": "Oynatma listesi ayarlayın (satır başına bir)",
    "trusteddomains-msgbox-label": "Etki alanları otomatik olarak geçiş yapmakta sorun yoktur (her satırda bir)",

    "createcontrolledroom-msgbox-label": "Yönetilen oda oluştur",
    "controlledroominfo-msgbox-label": "Yönetilen odanın adını girin\r\n(kullanım talimatları için https://syncplay.pl/guide/ adresine bakın):",

    "identifyascontroller-msgbox-label": "Oda operatörü olarak tanımlayın",
    "identifyinfo-msgbox-label": "Bu oda için operatör şifresini girin\r\n(kullanım talimatları için https://syncplay.pl/guide/ adresine bakın):",

    "public-server-msgbox-label": "Bu görüntüleme oturumu için genel sunucuyu seçin",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Bağlanılacak ana bilgisayar adı veya IP, isteğe bağlı olarak bağlantı noktası dahil (ör. Syncplay.pl:8999). Yalnızca aynı sunucu/bağlantı noktasındaki kişilerle senkronize edilir.",
    "name-tooltip": "Takma adınız tarafından tanınacaksınız. Kayıt yok, bu nedenle daha sonra kolayca değiştirebilirsiniz. Hiçbiri belirtilmediyse rastgele ad oluşturuldu.",
    "password-tooltip": "Parolalar yalnızca özel sunuculara bağlanmak için gereklidir.",
    "room-tooltip": "Bağlantı kurulduğunda katılabileceğiniz oda neredeyse her şey olabilir, ancak yalnızca aynı odadaki kişilerle senkronize olacaksınız.",

    "edit-rooms-tooltip": "Oda listesini düzenleyin.",

    "executable-path-tooltip": "Seçtiğiniz desteklenen medya oynatıcının konumu (mpv, mpv.net, VLC, MPC-HC / BE, mplayer2 veya IINA).",
    "media-path-tooltip": "Açılacak videonun veya akışın konumu. Mplayer2 için gerekli.",
    "player-arguments-tooltip": "Bu medya oynatıcıya iletilecek ek komut satırı argümanları / anahtarları.",
    "mediasearcdirectories-arguments-tooltip": "Syncplay'in medya dosyalarını arayacağı dizinler, ör. geçmek için tıklama özelliğini kullandığınızda. Syncplay, alt klasörler arasında yinelemeli olarak bakacaktır.",

    "more-tooltip": "Daha az kullanılan ayarları görüntüleyin.",
    "filename-privacy-tooltip": "Oynatılmakta olan dosya adını sunucuya göndermek için gizlilik modu.",
    "filesize-privacy-tooltip": "Oynatılmakta olan dosyanın boyutunu sunucuya göndermek için gizlilik modu.",
    "privacy-sendraw-tooltip": "Bu bilgileri şaşırtmadan gönderin. Bu, çoğu işlevselliğe sahip varsayılan seçenektir.",
    "privacy-sendhashed-tooltip": "Bilginin karma bir versiyonunu göndererek diğer istemciler tarafından daha az görünür hale getirin.",
    "privacy-dontsend-tooltip": "Bu bilgiyi sunucuya göndermeyin. Bu, maksimum gizlilik sağlar.",
    "checkforupdatesautomatically-tooltip": "Syncplay'in yeni bir sürümünün mevcut olup olmadığını görmek için Syncplay web sitesine düzenli olarak danışın.",
    "autosavejoinstolist-tooltip": "Sunucudaki bir odaya katıldığınızda, katılacağınız odalar listesindeki oda adını otomatik olarak hatırlayın.",
    "slowondesync-tooltip": "Sizi diğer izleyicilerle senkronize hale getirmek için gerektiğinde oynatma oranını geçici olarak azaltın. MPC-HC/BE'de desteklenmez.",
    "dontslowdownwithme-tooltip": "Oynatma işleminiz geciktiğinde başkalarının yavaşlamaması veya geri sarılmaması anlamına gelir. Oda operatörleri için kullanışlıdır.",
    "pauseonleave-tooltip": "Bağlantınız kesilirse veya biri odanızdan ayrılırsa oynatmayı duraklatın.",
    "readyatstart-tooltip": "Başlangıçta kendinizi 'hazır' olarak ayarlayın (aksi takdirde hazır olma durumunuzu değiştirene kadar 'hazır değil' olarak ayarlanırsınız)",
    "forceguiprompt-tooltip": "Syncplay ile bir dosya açarken yapılandırma diyaloğu gösterilmiyor.",  # (Inverted)
    "nostore-tooltip": "Syncplay'i verilen yapılandırmayla çalıştırın, ancak değişiklikleri kalıcı olarak saklamayın.",  # (Inverted)
    "rewindondesync-tooltip": "Tekrar senkronize olmak için gerektiğinde geri gidin. Bu seçeneğin devre dışı bırakılması büyük desenkronizasyonlara neden olabilir!",
    "fastforwardondesync-tooltip": "Oda operatörüyle senkronizasyon dışındayken ileri atlayın (veya 'Başkalarını asla yavaşlatma veya geri sarma' etkinse taklit konumunuz).",
    "showosd-tooltip": "Syncplay mesajlarını medya oynatıcı OSD'sine gönderir.",
    "showosdwarnings-tooltip": "Farklı bir dosya oynatılıyorsa, odada tek başına, kullanıcılar hazır değilse vb. Uyarıları gösterin.",
    "showsameroomosd-tooltip": "Oda kullanıcısının bulunduğu yerle ilgili olaylar için OSD bildirimlerini göster.",
    "shownoncontrollerosd-tooltip": "Yönetilen odalarda bulunan operatör olmayanlarla ilgili olaylar için OSD bildirimlerini gösterin.",
    "showdifferentroomosd-tooltip": "Oda kullanıcısının içinde olmadığı ile ilgili olaylar için OSD bildirimlerini göster.",
    "showslowdownosd-tooltip": "Zaman farkında yavaşlama / geri dönme bildirimlerini gösterin.",
    "showdurationnotification-tooltip": "Çok parçalı bir dosyadaki bir segment eksik olduğunda kullanışlıdır, ancak yanlış pozitiflere neden olabilir.",
    "language-tooltip": "Syncplay tarafından kullanılacak dil.",
    "unpause-always-tooltip": "Yeniden duraklatmaya basarsanız, yalnızca sizi hazır olarak ayarlamak yerine, her zaman hazır ve duraklatmaya devam etmenizi sağlar.",
    "unpause-ifalreadyready-tooltip": "Hazır olmadığınızda yeniden duraklatmaya basarsanız, sizi hazır olarak ayarlar - devam ettirmek için yeniden duraklatmaya basın.",
    "unpause-ifothersready-tooltip": "Hazır olmadığınızda duraklatmayı kaldır'a basarsanız, yalnızca başkaları hazırsa duraklatmaya devam eder.",
    "unpause-ifminusersready-tooltip": "Hazır değilken duraklatmayı kaldır'a basarsanız, yalnızca başkaları hazırsa ve minimum kullanıcı eşiğine ulaşılırsa duraklatmaya devam edilir.",
    "trusteddomains-arguments-tooltip": "Syncplay'in, paylaşılan oynatma listeleri etkinleştirildiğinde otomatik olarak geçiş yapmasının uygun olduğu alanlar.",

    "chatinputenabled-tooltip": "MPv'de sohbet girişini etkinleştirin (sohbet için enter'a basın, göndermek için enter'a basın, iptal etmek için çıkış yapın)",
    "chatdirectinput-tooltip": "Mpv'de sohbet giriş moduna geçmek için 'enter' tuşuna basma zorunluluğunu atlayın. Bu özelliği geçici olarak devre dışı bırakmak için mpv'de TAB tuşuna basın.",
    "font-label-tooltip": "Mpv'de sohbet mesajlarını girerken kullanılan yazı tipi. Yalnızca istemci tarafındadır, bu nedenle diğerlerinin gördüklerini etkilemez.",
    "set-input-font-tooltip": "Mpv'de sohbet mesajlarını girerken kullanılan yazı tipi ailesi. Yalnızca istemci tarafındadır, bu nedenle diğerlerinin gördüklerini etkilemez.",
    "set-input-colour-tooltip": "Mpv'de sohbet mesajlarını girerken kullanılan yazı tipi rengi. Yalnızca istemci tarafındadır, bu nedenle diğerlerinin gördüklerini etkilemez.",
    "chatinputposition-tooltip": "Enter tuşuna basıp yazdığınızda sohbet giriş metninin görüneceği mpv'deki konum.",
    "chatinputposition-top-tooltip": "Sohbet girişini mpv penceresinin üstüne yerleştirin.",
    "chatinputposition-middle-tooltip": "Sohbet girişini mpv penceresinin tam ortasına yerleştirin.",
    "chatinputposition-bottom-tooltip": "Sohbet girişini mpv penceresinin altına yerleştirin.",
    "chatoutputenabled-tooltip": "OSD'de sohbet mesajlarını gösterin (medya oynatıcı tarafından destekleniyorsa).",
    "font-output-label-tooltip": "Sohbet yazı tipi.",
    "set-output-font-tooltip": "Sohbet mesajlarını görüntülerken kullanılan yazı tipi.",
    "chatoutputmode-tooltip": "Sohbet mesajları nasıl görüntülenir.",
    "chatoutputmode-chatroom-tooltip": "Yeni sohbet satırlarını doğrudan önceki satırın altında görüntüleyin.",
    "chatoutputmode-scrolling-tooltip": "Sohbet metnini sağdan sola kaydırın.",

    "help-tooltip": "Syncplay.pl kullanım kılavuzunu açar.",
    "reset-tooltip": "Tüm ayarları varsayılan yapılandırmaya sıfırlayın.",
    "update-server-list-tooltip": "Genel sunucuların listesini güncellemek için syncplay.pl'ye bağlanın.",

    "sslconnection-tooltip": "Sunucuya güvenli bir şekilde bağlı. Sertifika detayları için tıklayınız.",

    "joinroom-tooltip": "Mevcut odadan çıkın ve belirtilen odaya katılır.",
    "seektime-msgbox-label": "Belirtilen zamana atlayın (saniye / dakika:saniye). Göreceli atlama için +/- kullanın.",
    "ready-tooltip": "İzlemeye hazır olup olmadığınızı gösterir.",
    "autoplay-tooltip": "Hazır olma göstergesine sahip tüm kullanıcılar hazır olduğunda ve minimum kullanıcı eşiğine ulaşıldığında otomatik oynatın.",
    "switch-to-file-tooltip": "Çift tıklama ile şuna geç {}",  # Filename
    "sendmessage-tooltip": "Odaya mesaj gönder",

    # In-userlist notes (GUI)
    "differentsize-note": "Farklı boyut!",
    "differentsizeandduration-note": "Farklı boyut ve süre!",
    "differentduration-note": "Farklı süre!",
    "nofile-note": "(Oynatılan dosya yok)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Syncplay {} kullanıyorsunuz ancak daha yeni bir sürüm https://syncplay.pl adresinde mevcut",  # ClientVersion
    "persistent-rooms-notice": "DİKKAT: Bu sunucu kalıcı odalar kullanır; bu, oynatma oturumları arasında oynatma listesi bilgilerinin saklandığı anlamına gelir. Bilgilerin kaydedilmediği bir oda oluşturmak istiyorsanız oda adının sonuna -temp koyun.",
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Syncplay sunucusuna hoş geldiniz, ver. {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) odaya bağlandı '{1}'",  # username, host, room
    "client-left-server-notification": "{0} sunucudan ayrıldı",  # name
    "no-salt-notification": "LÜTFEN DİKKAT: Bu sunucu örneği tarafından oluşturulan oda operatörü şifrelerinin sunucu yeniden başlatıldığında da çalışmasına izin vermek için, lütfen gelecekte Syncplay sunucusunu çalıştırırken aşağıdaki komut satırı bağımsız değişkenini ekleyin: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Ağ üzerinden birden çok medya oynatıcı örneğinin oynatılmasını senkronize etme çözümü. Sunucu örneği',
    "server-argument-epilog": 'Sağlanan seçenek yoksa _config değerleri kullanılacaktır',
    "server-port-argument": 'sunucu TCP bağlantı noktası',
    "server-password-argument": 'sunucu parolası',
    "server-isolate-room-argument": 'odalar izole edilmeli mi?',
    "server-salt-argument": "yönetilen oda şifreleri oluşturmak için kullanılan rastgele dize",
    "server-disable-ready-argument": "hazır olma özelliğini devre dışı bırak",
    "server-motd-argument": "motd alınacak dosyanın yolu",
    "server-rooms-argument": "kalıcı oda verilerini depolamak için kullanılacak ve/veya oluşturulacak veritabanı dosyasının yolu. Odaların gözlemciler olmadan ve yeniden başlatmalar yoluyla varlığını sürdürmesini sağlar",
    "server-permanent-rooms-argument": "oda boş olsa bile listelenecek kalıcı odaları listeleyen dosyanın yolu (satır başına bir odayı listeleyen bir metin dosyası biçiminde) - kalıcı odaların etkinleştirilmesini gerektirir",
    "server-chat-argument": "Sohbet devre dışı bırakılmalı mı?",
    "server-chat-maxchars-argument": "Bir sohbet mesajındaki maksimum karakter sayısı (varsayılan: {})", # Default number of characters
    "server-maxusernamelength-argument": "Bir kullanıcı adındaki maksimum karakter sayısı (varsayılan {})",
    "server-stats-db-file-argument": "SQLite db dosyasını kullanarak sunucu istatistiklerini etkinleştirin",
    "server-startTLS-argument": "Dosya yolundaki sertifika dosyalarını kullanarak TLS bağlantılarını etkinleştirin",
    "server-messed-up-motd-unescaped-placeholders": "Günün Mesajında çıkış karaktersiz yer tutucular var. Tüm $ işaretleri iki katına çıkarılmalıdır ($$).",
    "server-messed-up-motd-too-long": "Günün Mesajı çok uzun - maksimum {} karakter olmalı, {} verildi.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Bilinmeyen komut {}",  # message
    "not-json-server-error": "JSON ile kodlanmış bir dize değil {}",  # message
    "line-decode-server-error": "Utf-8 dizesi değil",
    "not-known-server-error": "Bu komutu göndermeden önce sunucu tarafından bilinmelisiniz",
    "client-drop-server-error": "İstemci bırakma: {} -- {}",  # host, error
    "password-required-server-error": "Parola gerekli",
    "wrong-password-server-error": "Yanlış parola sağlandı",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{} oynatma listesi seçimini değiştirdi",  # Username
    "playlist-contents-changed-notification": "{} oynatma listesini güncelledi",  # Username
    "cannot-find-file-for-playlist-switch-error": "Çalma listesi anahtarı için medya dizinlerinde {} dosyası bulunamadı!",  # Filename
    "cannot-add-duplicate-error": "Yinelemelere izin verilmediğinden oynatma listesine '{}' için ikinci giriş eklenemedi.",  # Filename
    "cannot-add-unsafe-path-error": "Güvenilir bir alanda olmadığı için {} otomatik olarak yüklenemedi. Oynatma listesinde çift tıklayarak URL'ye manuel olarak geçebilir ve Dosya-> Gelişmiş-> Güvenilir Etki Alanlarını Ayarla aracılığıyla güvenilir etki alanları ekleyebilirsiniz. Bir URL'yi sağ tıklarsanız, o URL'nin etki alanını bağlam menüsü aracılığıyla güvenilen etki alanı olarak ekleyebilirsiniz.",  # Filename
    "sharedplaylistenabled-label": "Oynatma listesi paylaşımını etkinleştir",
    "removefromplaylist-menu-label": "Oynatma listesinden kaldır",
    "shuffleremainingplaylist-menu-label": "Kalan oynatma listesini karıştır",
    "shuffleentireplaylist-menu-label": "Tüm oynatma listesini karıştır",
    "undoplaylist-menu-label": "Oynatma listesindeki son değişikliği geri al",
    "addfilestoplaylist-menu-label": "Oynatma listesinin altına dosya(lar) ekle",
    "addurlstoplaylist-menu-label": "Oynatma listesinin altına URL('ler) ekle",
    "editplaylist-menu-label": "Oynatma listesini düzenle",

    "open-containing-folder": "Bu dosyayı içeren klasörü aç",
    "addyourfiletoplaylist-menu-label": "Dosyanızı oynatma listesine ekleyin",
    "addotherusersfiletoplaylist-menu-label": "{} kişisinin dosyasını oynatma listesine ekle",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Akışınızı oynatma listesine ekleyin",
    "addotherusersstreamstoplaylist-menu-label": "Oynatma listesine {} kişisinin akışını ekleyin",  # [Username]
    "openusersstream-menu-label": "{} kişisinin akışını açın",  # [username]'s
    "openusersfile-menu-label": "{} kişisinin dosyasını açın",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Dosyayı paylaşılan çalma listesine eklemek için buraya sürükleyin.",
    "sharedplaylistenabled-tooltip": "Oda operatörleri, herkesin aynı şeyi izlemesini kolaylaştırmak için senkronize edilmiş bir çalma listesine dosya ekleyebilir. 'Misc' altında ortam dizinlerini yapılandırın.",

    "playlist-empty-error": "Oynatma listesi şu anda boş.",
    "playlist-invalid-index-error": "Geçersiz oynatma listesi dizini",
}



# coding:utf8

"""Portugal Portuguese dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

pt_PT = {
    "LANGUAGE": "Português de Portugal",
    "LANGUAGE-TAG": "pt_PT",

    # Strings for Windows NSIS installer
    "installer-language-file": "Portuguese.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Associar Syncplay aos ficheiros multimédia.",
    "installer-shortcut": "Criar atalhos nos seguintes locais:",
    "installer-start-menu": "Menu Iniciar",
    "installer-desktop": "Área de trabalho",
    "installer-quick-launch-bar": "Barra de acesso rápido",
    "installer-automatic-updates": "Verificar atualizações automaticamente",
    "installer-uninstall-configuration": "Apagar ficheiro de configuração.",

    # Client notifications
    "config-cleared-notification": "Configurações removidas. As mudanças serão salvas quando você armazenar uma configuração válida.",

    "relative-config-notification": "Ficheiro(s) de configuração relativa carregado(s): {}",

    "connection-attempt-notification": "Tentando se conectar a {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Conexão com o servidor perdida, tentando reconectar",
    "disconnection-notification": "Desconectado do servidor",
    "connection-failed-notification": "Conexão com o servidor falhou",
    "connected-successful-notification": "Conectado com sucesso ao servidor",
    "retrying-notification": "%s, tentando novamente em %d segundos...",  # Seconds
    "reachout-successful-notification": "Alcançado {} ({}) com sucesso",

    "rewind-notification": "Retrocedendo devido à diferença de tempo com {}",  # User
    "fastforward-notification": "Avançando devido à diferença de tempo com {}",  # User
    "slowdown-notification": "Diminuindo a velocidade devido à diferença de tempo com {}",  # User
    "revert-notification": "Revertendo velocidade ao normal",

    "pause-notification": "{} pausou ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{} despausou",  # User
    "seek-notification": "{} saltou de {} para {}",  # User, from time, to time

    "current-offset-notification": "Deslocamento atual: {} segundos",  # Offset

    "media-directory-list-updated-notification": "Os pastas de mídia do Syncplay foram atualizados.",

    "room-join-notification": "{} entrou na sala: '{}'",  # User
    "left-notification": "{} saiu da sala",  # User
    "left-paused-notification": "{} saiu da sala, {} pausou",  # User who left, User who paused
    "playing-notification": "{} está reproduzinho '{}' ({})",  # User, file, duration
    "playing-notification/room-addendum":  " na sala: '{}'",  # Room

    "not-all-ready": "Não está pronto: {}",  # Usernames
    "all-users-ready": "Todos utilizadores estão prontos ({} users)",  # Number of ready users
    "ready-to-unpause-notification": "Agora você está definido como pronto - despause novamente para despausar",
    "set-as-ready-notification": "Agora você está definido como pronto",
    "set-as-not-ready-notification": "Agora você está definido como não pronto",
    "autoplaying-notification": "Reprodução automática em {}...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Identificando-se como administrador da sala com a senha '{}'...",
    "failed-to-identify-as-controller-notification": "{} falhou ao se identificar como administrador da sala.",
    "authenticated-as-controller-notification": "{} autenticou-se como um administrador da sala",
    "created-controlled-room-notification": "Criou a sala controlada '{}' com a senha '{}'. Por favor, guarda essa informação para futura referência!\n\nIn managed rooms everyone is kept in sync with the room operator(s) who are the only ones who can pause, unpause, seek, and change the playlist.\n\nYou should ask regular viewers to join the room '{}' but the room operators can join the room '{}' to automatically authenticate themselves.", # RoomName, operatorPassword, roomName, roomName:operatorPassword # TODO: Translate

    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "O ficheiro que você está tocando parece ser diferente do ficheiro de {}",  # User
    "file-differences-notification": "Seus ficheiros se diferem da(s) seguinte(s) forma(s): {}",  # Differences
    "room-file-differences": "Diferenças de ficheiros: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "nome",
    "file-difference-filesize": "tamanho",
    "file-difference-duration": "duração",
    "alone-in-the-room": "Você está sozinho na sala",

    "different-filesize-notification": " (o tamanho do ficheiro deles é diferente do seu!)",
    "userlist-playing-notification": "{} está tocando:",  # Username
    "file-played-by-notification": "Ficheiro: {} está sendo reproduzido por:",  # File
    "no-file-played-notification": "{} não está reproduzinho um ficheiro",  # Username
    "notplaying-notification": "Pessoas que não estão reproduzinho nenhum ficheiro:",
    "userlist-room-notification":  "Na sala '{}':",  # Room
    "userlist-file-notification": "Ficheiro",
    "controller-userlist-userflag": "Administrador",
    "ready-userlist-userflag": "Pronto",

    "update-check-failed-notification": "Não foi possível verificar automaticamente se o Syncplay {} é a versão mais recente. Deseja visitar https://syncplay.pl/  para verificar manualmente por atualizações?",  # Syncplay version
    "syncplay-uptodate-notification": "O Syncplay está atualizado",
    "syncplay-updateavailable-notification": "Uma nova versão do Syncplay está disponível. Deseja visitar a página de lançamentos?",

    "mplayer-file-required-notification": "Syncplay com mplayer requer que você forneça o ficheiro ao começar",
    "mplayer-file-required-notification/example": "Exemplo de uso: syncplay [opções] [url|caminho_ate_o_ficheiro/]nome_do_ficheiro",
    "mplayer2-required": "O Syncplay é incompatível com o MPlayer 1.x, por favor use mplayer2 ou mpv",

    "unrecognized-command-notification": "Comando não reconhecido",
    "commandlist-notification": "Comandos disponíveis:",
    "commandlist-notification/room": "\tr [nome] - muda de sala",
    "commandlist-notification/list": "\tl - mostra lista de utilizadores",
    "commandlist-notification/undo": "\tu - desfaz último salto",
    "commandlist-notification/pause": "\tp - alterna pausa",
    "commandlist-notification/seek": "\t[s][+-]time - salta para o valor de tempo dado, se + ou - não forem especificados, será o tempo absoluto em segundos ou minutos:segundos",
    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
    "commandlist-notification/help": "\th - esta mensagem de ajuda",
    "commandlist-notification/toggle": "\tt - alterna o seu status de prontidão para assistir",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [nome] - cria sala gerenciada usando o nome da sala atual",
    "commandlist-notification/auth": "\ta [senha] - autentica-se como administrador da sala com a senha",
    "commandlist-notification/chat": "\tch [mensagem] - envia uma mensagem no chat da sala",
    "commandList-notification/queue": "\tqa [file/url] - add file or url to bottom of playlist",  # TO DO: Translate
    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",  # TO DO: Translate
    "commandList-notification/playlist": "\tql - show the current playlist",  # TO DO: Translate
    "commandList-notification/select": "\tqs [index] - select given entry in the playlist",  # TO DO: Translate
    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
    "commandList-notification/delete": "\tqd [index] - delete the given entry from the playlist",  # TO DO: Translate
    "syncplay-version-notification": "Versão do Syncplay: {}",  # syncplay.version
    "more-info-notification": "Mais informações disponíveis em: {}",  # projectURL

    "gui-data-cleared-notification": "O Syncplay limpou o caminho e o estado de dados da janela usados pela GUI.",
    "language-changed-msgbox-label": "O idioma será alterado quando você salvar as alterações e reabrir o Syncplay.",
    "promptforupdate-label": "O Syncplay pode verificar automaticamente por atualizações de tempos em tempos?",

    "media-player-latency-warning": "Aviso: O reprodutor de mídia demorou {} para responder. Se você tiver problemas de sincronização, desligue outros programas para libertar recursos do sistema e, se isso não funcionar, tente outro reprodutor de mídia.",  # Seconds to respond
    "mpv-unresponsive-error": "O mpv não respondeu por {} segundos, portanto parece que não está funcionando. Por favor, reinicie o Syncplay.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Aperte Enter para sair\n",

    # Client errors
    "missing-arguments-error": "Alguns argumentos necessários estão faltando, por favor reveja --help",
    "server-timeout-error": "A conexão com o servidor ultrapassou o tempo limite",
    "mpc-slave-error": "Não foi possível abrir o MPC no slave mode!",
    "mpc-version-insufficient-error": "A versão do MPC é muito antiga, por favor use `mpc-hc` >= `{}`",
    "mpc-be-version-insufficient-error": "A versão do MPC-BE é muito antiga, por favor use `mpc-be` >= `{}`",
    "mpv-version-error": "O Syncplay não é compatível com esta versão do mpv. Por favor, use uma versão diferente do mpv (por exemplo, Git HEAD).",
    "mpv-failed-advice": "O motivo pelo qual o mpv não pode ser iniciado pode ser devido ao uso de argumentos da linha de comando não suportados ou a uma versão não suportada do mpv.", # TODO: Translate
    "player-file-open-error": "O reprodutor falhou ao abrir o ficheiro",
    "player-path-error": "O caminho até o ficheiro executável do reprodutor não está configurado corretamente. Os reprodutores suportados são: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 e IINA",
    "hostname-empty-error": "O endereço do servidor não pode ser vazio",
    "empty-error": "{} não pode ser vazio",  # Configuration
    "media-player-error": "Erro do reprodutor de mídia: \"{}\"",  # Error line
    "unable-import-gui-error": "Não foi possível importar bibliotecas da GUI. Se você não possuir o PySide instalado, instale-o para que a GUI funcione. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "Não foi possível importar o Twisted. Por favor, instale o Twisted v16.4.0 ou superior.",

    "arguments-missing-error": "Alguns argumentos necessários estão faltando, por favor reveja --help",

    "unable-to-start-client-error": "Não foi possível iniciar o client",

    "player-path-config-error": "O caminho até o ficheiro executável do reprodutor não está configurado corretamente. Os reprodutores suportados são: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 e IINA.",
    "no-file-path-config-error": "O ficheiro deve ser selecionado antes de iniciar seu reprodutor",
    "no-hostname-config-error": "O endereço do servidor não pode ser vazio",
    "invalid-port-config-error": "A porta deve ser válida",
    "empty-value-config-error": "{} não pode ser vazio",  # Config option

    "not-json-error": "Não é uma string codificada como JSON\n",
    "hello-arguments-error": "Falta de argumentos Hello\n",  # DO NOT TRANSLATE
    "version-mismatch-error": "Discrepância entre versões do cliente e do servidor\n",
    "vlc-failed-connection": "Falha ao conectar ao VLC. Se você não instalou o syncplay.lua e está usando a versão mais recente do VLC, por favor veja https://syncplay.pl/LUA/ para mais instruções.Syncplay and VLC 4 are not currently compatible, so either use VLC 3 or an alternative such as mpv.", # TO DO: TRANSLATE
    "vlc-failed-noscript": "O VLC reportou que a interface de script do syncplay.lua não foi instalada. Por favor, veja https://syncplay.pl/LUA/ para mais instruções.",
    "vlc-failed-versioncheck": "Esta versão do VLC não é suportada pelo Syncplay.",
    "vlc-initial-warning": 'VLC does not always provide accurate position information to Syncplay, especially for .mp4 and .avi files. If you experience problems with erroneous seeking then please try an alternative media player such as <a href="https://mpv.io/">mpv</a> (or <a href="https://github.com/stax76/mpv.net/">mpv.net</a> for Windows users).', # TODO: Translate

    "feature-sharedPlaylists": "playlists compartilhadas",  # used for not-supported-by-server-error
    "feature-chat": "chat",  # used for not-supported-by-server-error
    "feature-readiness": "prontidão",  # used for not-supported-by-server-error
    "feature-managedRooms": "salas administradas",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "O recurso {} não é suportado por este servidor.",  # feature
    "shared-playlists-not-supported-by-server-error": "O recurso de playlists compartilhadas pode não ser suportado por este servidor. Para garantir que funcione corretamente, é necessário um servidor a correr Syncplay {} ou superior, mas este está correndoo Syncplay {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "O recurso de playlists compartilhadas foi desativado nas configurações do servidor. Para usar este recurso, você precisa se conectar a um servidor diferente.",

    "invalid-seek-value": "Valor de salto inválido",
    "invalid-offset-value": "Valor de deslocamento inválido",

    "switch-file-not-found-error": "Não foi possível mudar para o ficheiro '{0}'. O Syncplay procura nos pastas de mídia especificados.",  # File not found
    "folder-search-timeout-error": "A busca por mídias no pasta de mídias foi cancelada pois demorou muito tempo para procurar em '{}' (after having processed the first {} files). Isso ocorre quando você seleciona uma pasta com muitas subpastas em sua lista de pastas de mídias a serem pesquisadas.  Para que a troca automática de ficheiros funcione novamente, selecione 'Ficheiro -> Definir pastas de mídias' na barra de menus e remova esse pasta ou substitua-o por uma subpasta apropriada. Se a pasta não tiver problemas, é possível reativá-la selecionando 'Ficheiro -> Definir pastas de mídias' e pressionando 'OK'.",  # Folder, Files processed - TODO: Update translation (refer back to original English text)
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "A busca por mídias em '{}' foi interrompida, pois demorou muito para acessar o pasta. Isso pode acontecer se for uma unidade de rede ou se você configurar o seu dispositivo para hibernar depois de um período de inatividade. Para que a troca automática de ficheiros funcione novamente, vá para 'Ficheiro -> Definir pastas de mídias' e remova o pasta ou resolva o problema (por exemplo, alterando as configurações de economia de energia da unidade).",  # Folder
    "added-file-not-in-media-directory-error": "Você carregou um ficheiro em '{}', que não é um pasta de mídias conhecido. Você pode adicioná-lo isso como um pasta de mídia selecionando 'Ficheiro -> Definir pastas de mídias' na barra de menus.",  # Folder
    "no-media-directories-error": "Nenhum pasta de mídias foi definido. Para que os recursos de playlists compartilhadas e troca automática de ficheiros funcionem corretamente, selecione 'Ficheiro -> Definir pastas de mídias' e especifique onde o Syncplay deve procurar para encontrar ficheiros de mídia.",
    "cannot-find-directory-error": "Não foi possível encontrar o pasta de mídia '{}'. Para atualizar sua lista de pastas de mídias, selecione 'Ficheiro -> Definir pastas de mídias' na barra de menus e especifique onde o Syncplay deve procurar para encontrar ficheiros de mídia.",

    "failed-to-load-server-list-error": "Não foi possível carregar a lista de servidores públicos. Por favor, visite https://www.syncplay.pl/ em seu navegador.",

    # Client arguments
    "argument-description": 'Solução para sincronizar reprodução de múltiplas instâncias de reprodutores de mídia pela rede.',
    "argument-epilog": 'Se nenhuma opção for fornecida, os valores de _config serão usados',
    "nogui-argument": 'não mostrar GUI',
    "host-argument": 'endereço do servidor',
    "name-argument": 'nome de utilizador desejado',
    "debug-argument": 'modo depuração',
    "force-gui-prompt-argument": 'fazer o prompt de configuração aparecer',
    "no-store-argument": 'não guardar valores em .syncplay',
    "room-argument": 'sala padrão',
    "password-argument": 'senha do servidor',
    "player-path-argument": 'caminho até o executável do reprodutor de mídia',
    "file-argument": 'ficheiro a ser tocado',
    "args-argument": 'opções do reprodutor; se você precisar passar opções começando com -, as preceda com um único argumento \'--\'',
    "clear-gui-data-argument": 'redefine o caminho e o estado de dados da janela da GUI para as de QSettings',
    "language-argument": 'idioma para mensagens do Syncplay ({})', # Languages

    "version-argument": 'exibe sua versão',
    "version-message": "Você está usando o Syncplay versão {} ({})",

    "load-playlist-from-file-argument": "carrega playlist de um ficheiro de texto (uma entrada por linha)",

    # Client labels
    "config-window-title": "Configuração do Syncplay",

    "connection-group-title": "Configurações de conexão",
    "host-label": "Endereço do servidor: ",
    "name-label": "Nome de utilizador (opcional): ",
    "password-label": "Senha do servidor (se existir): ",
    "room-label": "Sala padrão: ",
    "roomlist-msgbox-label": "Edit room list (one per line)", # TODO: Translate

    "media-setting-title": "Configurações do reprodutor de mídia",
    "executable-path-label": "Executável do reprodutor:",
    "media-path-label": "Ficheiro de vídeo ou URL (opcional):",
    "player-arguments-label": "Argumentos para o reprodutor (opcional):",
    "browse-label": "Navegar",
    "update-server-list-label": "Atualizar lista",

    "more-title": "Mostrar mais configurações",
    "never-rewind-value": "Nunca",
    "seconds-suffix": " s",
    "privacy-sendraw-option": "Enviar bruto",
    "privacy-sendhashed-option": "Enviar hasheado",
    "privacy-dontsend-option": "Não enviar",
    "filename-privacy-label": "Informação do nome do ficheiro:",
    "filesize-privacy-label": "Informação do tamanho do ficheiro:",
    "checkforupdatesautomatically-label": "Verificar atualizações do Syncplay automaticamente",
    "slowondesync-label": "Diminuir velocidade em dessincronizações menores (não suportado pelo MPC-HC/BE)",
    "rewindondesync-label": "Retroceder em dessincronização maiores (recomendado)",
    "fastforwardondesync-label": "Avançar se estiver ficando para trás (recomendado)",
    "dontslowdownwithme-label": "Nunca desacelerar ou retroceder outros (experimental)",
    "pausing-title": "Pausando",
    "pauseonleave-label": "Pausar quando um utilizador sair (por exemplo, se for desconectado)",
    "readiness-title": "Estado de prontidão inicial",
    "readyatstart-label": "Marque-me como 'pronto para assistir' por padrão",
    "forceguiprompt-label": "Não mostrar sempre a janela de configuração do Syncplay",  # (Inverted)
    "showosd-label": "Ativar mensagens na tela (OSD)",

    "showosdwarnings-label": "Incluir avisos (por exemplo, quando os ficheiros são diferentes, os utilizador não estão prontos, etc)",
    "showsameroomosd-label": "Incluir eventos da sua sala",
    "shownoncontrollerosd-label": "Incluir eventos de não administradores em salas administradas",
    "showdifferentroomosd-label": "Incluir eventos de outras salas",
    "showslowdownosd-label": "Incluir notificações de desaceleramento ou retrocedimento",
    "language-label": "Idioma:",
    "automatic-language": "Padrão ({})",  # Default language
    "showdurationnotification-label": "Avisar sobre discrepância nas durações dos arquivos de mídia",
    "basics-label": "Básicos",
    "readiness-label": "Play/Pause",
    "misc-label": "Miscelânea",
    "core-behaviour-title": "Comportamento da sala padrão",
    "syncplay-internals-title": "Syncplay internals",
    "syncplay-mediasearchdirectories-title": "pastas a buscar por mídias",
    "syncplay-mediasearchdirectories-label": "pastas a buscar por mídias (um caminho por linha)",
    "sync-label": "Sincronizar",
    "sync-otherslagging-title": "Se outros estiverem ficando pra trás...",
    "sync-youlaggging-title": "Se você estiver ficando pra trás...",
    "messages-label": "Mensagens",
    "messages-osd-title": "Configurações das mensagens na tela (OSD)",
    "messages-other-title": "Outras configurações de tela",
    "chat-label": "Chat",
    "privacy-label": "Privacidade",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Configurações de privacidade",
    "unpause-title": "Se você apertar play, definir-se como pronto e:",
    "unpause-ifalreadyready-option": "Despausar se você já estiver definido como pronto",
    "unpause-ifothersready-option": "Despausar se você já estiver pronto ou outros na sala estiverem prontos (padrão)",
    "unpause-ifminusersready-option": "Despausar se você já estiver pronto ou outros na sala estiverem prontos e o número mínimo de utilizadores está pronto",
    "unpause-always": "Sempre despausar",
    "syncplay-trusteddomains-title": "Domínios confiáveis (para serviços de streaming e conteúdo hospedado)",

    "chat-title": "Entrada de mensagem do chat",
    "chatinputenabled-label": "Habilitar entrada de chat via mpv",
    "chatdirectinput-label": "Permitir entrada instantânea de chat (evita ter de apertar Enter para abrir o chat)",
    "chatinputfont-label": "Fonte da entrada de chat",
    "chatfont-label": "Definir fonte",
    "chatcolour-label": "Definir cor",
    "chatinputposition-label": "Posição da área de entrada de mensagens no mpv",
    "chat-top-option": "Topo",
    "chat-middle-option": "Meio",
    "chat-bottom-option": "Fundo",
    "chatoutputheader-label": "Saída de mensagem do chat",
    "chatoutputfont-label": "Fonte da saída de chat",
    "chatoutputenabled-label": "Habilitar saída de chat no reprodutor de mídia (apenas mpv por enquanto)",
    "chatoutputposition-label": "Modo de saída",
    "chat-chatroom-option": "Estilo sala de bate-papo",
    "chat-scrolling-option": "Estilo de rolagem",

    "mpv-key-tab-hint": "[TAB] para alternar acesso instantâneo ao chat.",
    "mpv-key-hint": "[ENTER] para enviar mensagem. [ESC] para sair do modo de chat.",
    "alphakey-mode-warning-first-line": "Você pode usar os antigos atalhos do mpv com as teclas A-Z.",
    "alphakey-mode-warning-second-line": "Aperte [TAB] para retornar ao modo de chat instantâneo do Syncplay.",

    "help-label": "Ajuda",
    "reset-label": "Restaurar padrões",
    "run-label": "Começar Syncplay",
    "storeandrun-label": "Salvar mudanças e começar Syncplay",

    "contact-label": "Sinta-se livre para enviar um e-mail para <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>abrir uma issue</nobr></a> pelo GitHub / <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> to make a suggestion or ask a question via GitHub,, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>curtir nossa página no Facebook</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>nos seguir no Twitter</nobr></a> ou visitar <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. Não use o Syncplay para mandar informações sensíveis/confidenciais.", # TODO: Update translation

    "joinroom-label": "Juntar-se a uma sala",
    "joinroom-menu-label": "Juntar-se à sala {}",
    "seektime-menu-label": "Saltar para o tempo",
    "undoseek-menu-label": "Desfazer salto",
    "play-menu-label": "Play",
    "pause-menu-label": "Pause",
    "playbackbuttons-menu-label": "Mostrar botões de reprodução",
    "autoplay-menu-label": "Mostrar botão de reprodução automática",
    "autoplay-guipushbuttonlabel": "Tocar quando todos estiverem prontos",
    "autoplay-minimum-label": "Mín. de utilizadores:",
    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate

    "sendmessage-label": "Enviar",

    "ready-guipushbuttonlabel": "Estou pronto para assistir!",

    "roomuser-heading-label": "Sala / Utilizador",
    "size-heading-label": "Tamanho",
    "duration-heading-label": "Duração",
    "filename-heading-label": "Nome do ficheiro",
    "notifications-heading-label": "Notificações",
    "userlist-heading-label": "Lista de quem está tocando o quê",

    "browseformedia-label": "Navegar por ficheiros de mídia",

    "file-menu-label": "&Ficheiro",  # & precedes shortcut key
    "openmedia-menu-label": "A&brir ficheiro de mídia",
    "openstreamurl-menu-label": "Abrir &URL de stream de mídia",
    "setmediadirectories-menu-label": "Definir &pastas de mídias",
    "loadplaylistfromfile-menu-label": "&Carregar playlist de ficheiro",
    "saveplaylisttofile-menu-label": "&Salvar playlist em ficheiro",
    "exit-menu-label": "&Sair",
    "advanced-menu-label": "A&vançado",
    "window-menu-label": "&Janela",
    "setoffset-menu-label": "Definir &deslocamento",
    "createcontrolledroom-menu-label": "&Criar sala administrada",
    "identifyascontroller-menu-label": "&Identificar-se como administrador da sala",
    "settrusteddomains-menu-label": "D&efinir domínios confiáveis",
    "addtrusteddomain-menu-label": "Adicionar {} como domínio confiável",  # Domain

    "edit-menu-label": "&Editar",
    "cut-menu-label": "Cor&tar",
    "copy-menu-label": "&Copiar",
    "paste-menu-label": "C&olar",
    "selectall-menu-label": "&Selecionar todos",

    "playback-menu-label": "&Reprodução",

    "help-menu-label": "&Ajuda",
    "userguide-menu-label": "Abrir &guia de utilizador",
    "update-menu-label": "&Verificar atualizações",

    "startTLS-initiated": "Tentando estabelecer conexão segura",
    "startTLS-secure-connection-ok": "Conexão segura estabelecida ({})",
    "startTLS-server-certificate-invalid": 'Não foi possível estabelecer uma conexão segura. O servidor usa um certificado de segurança inválido. Essa comunicação pode ser interceptada por terceiros. Para mais detalhes de solução de problemas, consulte <a href="https://syncplay.pl/trouble">aqui</a>.',
    "startTLS-server-certificate-invalid-DNS-ID": "O Syncplay não confia neste servidor porque usa um certificado que não é válido para o nome do host.", # TODO: Translate
    "startTLS-not-supported-client": "Este client não possui suporte para TLS",
    "startTLS-not-supported-server": "Este servidor não possui suporte para TLS",

    # TLS certificate dialog
    "tls-information-title": "Detalhes do certificado",
    "tls-dialog-status-label": "<strong>Syncplay está a usar uma conexão criptografada para {}.</strong>",
    "tls-dialog-desc-label": "A criptografia com um certificado digital mantém as informações em sigilo quando são enviadas para ou do<br/>servidor {}.",
    "tls-dialog-connection-label": "Informações criptografadas usando o Transport Layer Security (TLS), versão {} com o conjunto de cifras (cipher suite)<br/>: {}.",
    "tls-dialog-certificate-label": "Certificado emitido em {} e válido até {}.",

    # About dialog
    "about-menu-label": "&Sobre o Syncplay",
    "about-dialog-title": "Sobre o Syncplay",
    "about-dialog-release": "Versão {}, lançamento {}",
    "about-dialog-license-text": "Licenciado sob a Licença&nbsp;Apache,&nbsp;Versão 2.0",
    "about-dialog-license-button": "Licença",
    "about-dialog-dependencies": "Dependências",

    "setoffset-msgbox-label": "Definir deslocamento",
    "offsetinfo-msgbox-label": "Deslocamento (veja https://syncplay.pl/guide/ para instruções de uso):",

    "promptforstreamurl-msgbox-label": "Abrir transmissão de mídia via URL",
    "promptforstreamurlinfo-msgbox-label": "Transmitir URL",

    "addfolder-label": "Adicionar pasta",

    "adduris-msgbox-label": "Adicionar URLs à playlist (uma por linha)",
    "editplaylist-msgbox-label": "Definir playlist (uma por linha)",
    "trusteddomains-msgbox-label": "Domínios para os quais é permitido trocar automaticamente (um por linha)",

    "createcontrolledroom-msgbox-label": "Criar sala administrativa",
    "controlledroominfo-msgbox-label": "Informe o nome da sala administrativa\r\n(veja https://syncplay.pl/guide/ para instruções de uso):",

    "identifyascontroller-msgbox-label": "Identificar-se como administrador da sala",
    "identifyinfo-msgbox-label": "Informe a senha de administrador para esta sala\r\n(veja https://syncplay.pl/guide/ para instruções de uso):",

    "public-server-msgbox-label": "Selecione o servidor público para esta sessão de visualização",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Hostname ou IP para se conectar, opcionalmente incluindo uma porta (por exemplo, syncplay.pl:8999). Só sincroniza-se com utilizadores no mesmo servidor/porta.",
    "name-tooltip": "Nome pelo qual você será conhecido. Não há cadastro, então você pode facilmente mudar mais tarde. Se não for especificado, será gerado aleatoriamente.",
    "password-tooltip": "Senhas são necessárias apenas para servidores privados.",
    "room-tooltip": "O nome da sala para se conectar pode ser praticamente qualquer coisa, mas você só irá se sincronizar com utilizadores na mesma sala.",

    "edit-rooms-tooltip": "Edit room list.",  # TO DO: Translate

    "executable-path-tooltip": "Localização do seu reprodutor de mídia preferido (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 ou IINA).",
    "media-path-tooltip": "Localização do vídeo ou transmissão a ser aberto. Necessário com o mplayer2.",
    "player-arguments-tooltip": "Argumentos de comando de linha adicionais para serem repassados ao reprodutor de mídia.",
    "mediasearcdirectories-arguments-tooltip": "Pasta onde o Syncplay vai procurar por ficheiros de mídia, por exemplo quando você estiver usando o recurso de clicar para mudar. O Syncplay irá procurar recursivamente pelas subpastas.",

    "more-tooltip": "Mostrar configurações frequentemente menos utilizadas.",
    "filename-privacy-tooltip": "Modo de privacidade para mandar nome de ficheiro do ficheiro atual para o servidor.",
    "filesize-privacy-tooltip": "Modo de privacidade para mandar tamanho do ficheiro atual para o servidor.",
    "privacy-sendraw-tooltip": "Enviar esta informação sem ofuscação. Esta é a opção padrão com mais funcionalidades.",
    "privacy-sendhashed-tooltip": "Mandar versão hasheada da informação, tornando-a menos visível aos outros clients.",
    "privacy-dontsend-tooltip": "Não enviar esta informação ao servidor. Esta opção oferece a maior privacidade.",
    "checkforupdatesautomatically-tooltip": "Verificar o site do Syncplay regularmente para ver se alguma nova versão do Syncplay está disponível.",
    "autosavejoinstolist-tooltip": "When you join a room in a server, automatically remember the room name in the list of rooms to join.", # TO DO: Translate
    "autosavejoinstolist-label": "Add rooms you join to the room list", # TO DO: Translate
    "slowondesync-tooltip": "Reduzir a velocidade de reprodução temporariamente quando necessário para trazer você de volta à sincronia com os outros espectadores. Não suportado pelo MPC-HC/BE.",
    "dontslowdownwithme-tooltip": "Significa que outros não serão desacelerados ou retrocedidos se sua reprodução estiver ficando para trás. Útil para administradores de salas.",
    "pauseonleave-tooltip": "Pausar reprodução se você for disconectado ou se alguém sair da sua sala.",
    "readyatstart-tooltip": "Definir-se como 'pronto' ao começar (do contrário você será definido como 'não pronto' até mudar seu estado de prontidão)",
    "forceguiprompt-tooltip": "Diálogo de configuração não é exibido ao abrir um ficheiro com o Syncplay.",  # (Inverted)
    "nostore-tooltip": "Começar Syncplay com a dada configuração, mas não guardar as mudanças permanentemente.",  # (Inverted)
    "rewindondesync-tooltip": "Retroceder automaticamente quando necessário para sincronizar. Desabilitar isto pode resultar em grandes dessincronizações!",
    "fastforwardondesync-tooltip": "Avançar automaticamente quando estiver fora de sincronia com o administrador da sala (ou sua posição pretendida caso 'Nunca desacelerar ou retroceder outros' estiver habilitada).",
    "showosd-tooltip": "Envia mensagens do Syncplay à tela do reprodutor de mídia (OSD).",
    "showosdwarnings-tooltip": "Mostra avisos se: estiver tocando ficheiros diferentes, sozinho na sala, utilizadores não prontos, etc.",
    "showsameroomosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados à sala em que o utilizador está.",
    "shownoncontrollerosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados a não administradores que estão em salas gerenciadas.",
    "showdifferentroomosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados à sala em que o utilizador não está.",
    "showslowdownosd-tooltip": "Mostra notificações na tela (OSD) sobre desaceleramento/retrocedimento por conta de diferença nos tempos.",
    "showdurationnotification-tooltip": "Útil quando um segmento em um ficheiro de múltiplas partes está faltando, mas pode resultar em falsos positivos.",
    "language-tooltip": "Idioma a ser utilizado pelo Syncplay.",
    "unpause-always-tooltip": "Se você pressionar para despausar, sempre te definirá como pronto e despausará em vez de simplesmente te definir com pronto.",
    "unpause-ifalreadyready-tooltip": "Se você pressionar para despausar quando não estiver pronto, irá te definir como pronto - despause novamente para despausar.",
    "unpause-ifothersready-tooltip": "Se você apertar para despausar quando não estiver pronto, só irá despausar quando outros estiverem prontos.",
    "unpause-ifminusersready-tooltip": "Se você apertar para despausar quando não estiver pronto, só irá despausar quando outros estiverem prontos e o número mínimo de utilizadores for atingido.",
    "trusteddomains-arguments-tooltip": "Domínios para os quais é permitido trocar automaticamente quando as playlists compartilhadas estiverem habilitadas.",

    "chatinputenabled-tooltip": "Ativar entrada de chat via mpv (pressione Enter para escrever, Enter para enviar, ESC para cancelar)",
    "chatdirectinput-tooltip": "Evita ter de apertar 'Enter' para entrar no modo de entrada de chat no mpv. Pressione TAB no mpv para temporariamente desabilitar esta função.",
    "font-label-tooltip": "Fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "set-input-font-tooltip": "Família de fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "set-input-colour-tooltip": "Cor de fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "chatinputposition-tooltip": "Lugar no mpv onde a entrada de chat será exibida quando você apertar Enter e digitar.",
    "chatinputposition-top-tooltip": "Colocar entrada de chat no topo da janela do mpv.",
    "chatinputposition-middle-tooltip": "Colocar entrada de chat no meio da janela do mpv.",
    "chatinputposition-bottom-tooltip": "Colocar entrada de chat no fundo da janela do mpv.",
    "chatoutputenabled-tooltip": "Mostrar mensagens de chat na tela do reprodutor (OSD) (se suportado pelo reprodutor).",
    "font-output-label-tooltip": "Fonte da saída de chat.",
    "set-output-font-tooltip": "Fonte usada para exibir mensagens do chat.",
    "chatoutputmode-tooltip": "Como as mensagens do chat são exibidas.",
    "chatoutputmode-chatroom-tooltip": "Exibe novas linhas de chat diretamente abaixo da linha anterior.",
    "chatoutputmode-scrolling-tooltip": "Exibe novas linhas de chat rolando-as da direita pra esquerda.",

    "help-tooltip": "Abre o  guia de utilizadores do Syncplay.pl.",
    "reset-tooltip": "Redefine todas as configurações para seus respectivos padrões.",
    "update-server-list-tooltip": "Conecta ao syncplay.pl para atualizar a lista de servidores públicos.",

    "sslconnection-tooltip": "Conectado com segurança ao servidor. Clique para exibir detalhes do certificado.",

    "joinroom-tooltip": "Sair da sala atual e ingressar na sala especificada.",
    "seektime-msgbox-label": "Saltar para tempo especificado (em segundos ou minutos:segundos). Use + ou - para fazer um pulo relativo ao tempo atual.",
    "ready-tooltip": "Indica se você está pronto para assistir.",
    "autoplay-tooltip": "Reproduzir automaticamente quando todos os usuários que tiverem indicadores de prontidão estiverem prontos e o limiar de usuários for atingido.",
    "switch-to-file-tooltip": "Clique duas vezes para mudar para {}",  # Filename
    "sendmessage-tooltip": "Mandar mensagem para a sala",

    # In-userlist notes (GUI)
    "differentsize-note": "Tamanhos diferentes!",
    "differentsizeandduration-note": "Tamanhos e durações diferentes!",
    "differentduration-note": "Durações diferentes!",
    "nofile-note": "(Nenhum arquivo está sendo tocado)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Você está usando o Syncplay {}, mas uma versão mais nova está disponível em https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate - NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Seja bem-vindo ao servidor de Syncplay, versão {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) conectou-se à sala '{1}'",  # username, host, room
    "client-left-server-notification": "{0} saiu do servidor",  # name
    "no-salt-notification": "POR FAVOR, NOTE: Para permitir que as senhas de administradores de sala geradas por esta instância do servidor ainda funcionem quando o servidor for reiniciado, por favor, adicione o seguinte argumento de linha de comando ao executar o servidor de Syncplay no futuro: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Solução para sincronizar a reprodução de múltiplas instâncias de MPlayer e MPC-HC/BE pela rede. Instância de servidor',
    "server-argument-epilog": 'Se nenhuma opção for fornecida, os valores de _config serão utilizados',
    "server-port-argument": 'porta TCP do servidor',
    "server-password-argument": 'senha do servidor',
    "server-isolate-room-argument": 'salas devem ser isoladas?',
    "server-salt-argument": "string aleatória utilizada para gerar senhas de salas gerenciadas",
    "server-disable-ready-argument": "desativar recurso de prontidão",
    "server-motd-argument": "caminho para o arquivo o qual o motd será obtido",
    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
    "server-chat-argument": "O chat deve ser desativado?",
    "server-chat-maxchars-argument": "Número máximo de caracteres numa mensagem do chat (o padrão é {})", # Default number of characters
    "server-maxusernamelength-argument": "Número máximos de caracteres num nome de utilizador (o padrão é {})",
    "server-stats-db-file-argument": "Habilita estatísticas de servidor usando o arquivo db SQLite fornecido",
    "server-startTLS-argument": "Habilita conexões TLS usando os arquivos de certificado no caminho fornecido",
    "server-messed-up-motd-unescaped-placeholders": "A Mensagem do Dia possui placeholders não escapados. Todos os sinais de $ devem ser dobrados (como em $$).",
    "server-messed-up-motd-too-long": "A Mensagem do Dia é muito longa - máximo de {} caracteres, {} foram dados.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Comando desconhecido: {}",  # message
    "not-json-server-error": "Não é uma string codificada como JSON: {}",  # message
    "line-decode-server-error": "Não é uma string UTF-8",
    "not-known-server-error": "Você deve ser conhecido pelo servidor antes de mandar este comando",
    "client-drop-server-error": "Drop do client: {} -- {}",  # host, error
    "password-required-server-error": "Senha necessária",
    "wrong-password-server-error": "Senha incorreta fornecida",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{} mudou a seleção da playlist",  # Username
    "playlist-contents-changed-notification": "{} atualizou playlist",  # Username
    "cannot-find-file-for-playlist-switch-error": "Não foi possível encontrar o ficheiro {} no pastas de mídia para a troca de playlist!",  # Filename
    "cannot-add-duplicate-error": "Não foi possível adicionar uma segunda entrada para '{}' para a playlist uma vez que duplicatas não são permitidas.",  # Filename
    "cannot-add-unsafe-path-error": "Não foi possível automaticamente carregar {} porque este não é um domínio confiado. Você pode trocar para a URL manualmente dando um clique duplo nela na playlist e adicionando o domínio aos domínios confiáveis em 'Ficheiro -> Avançado -> Definir domínios confiáveis'. Se você clicar com o botão direito na URL, você pode adicionar esta URL como domínio confiável pelo menu de contexto.",  # Filename
    "sharedplaylistenabled-label": "Habilitar playlists compartilhadas",
    "removefromplaylist-menu-label": "Remover da playlist",
    "shuffleremainingplaylist-menu-label": "Embaralhar resto da playlist",
    "shuffleentireplaylist-menu-label": "Embaralhar toda a playlist",
    "undoplaylist-menu-label": "Desfazer última alteração à playlist",
    "addfilestoplaylist-menu-label": "Adicionar ficheiro(s) ao final da playlist",
    "addurlstoplaylist-menu-label": "Adicionar URL(s) ao final da playlist",
    "editplaylist-menu-label": "Editar playlist",

    "open-containing-folder": "Abrir pasta contendo este ficheiro",
    "addyourfiletoplaylist-menu-label": "Adicionar seu ficheiro à playlist",
    "addotherusersfiletoplaylist-menu-label": "Adicionar ficheiros de {} à playlist",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Adicionar sua transmissão à playlist",
    "addotherusersstreamstoplaylist-menu-label": "Adicionar transmissão de {} à playlist",  # [Username]
    "openusersstream-menu-label": "Abrir transmissão de {}",  # [username]'s
    "openusersfile-menu-label": "Abrir ficheiro de {}",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Arraste um ficheiro aqui para adicioná-lo à playlist compartilhada.",
    "sharedplaylistenabled-tooltip": "Operadores da sala podem adicionar ficheiros para a playlist compartilhada para tornar mais fácil para todo mundo assistir a mesma coisa. Configure os pastas de mídia em 'Miscelânea'.",

    "playlist-empty-error": "Playlist is currently empty.",  # TO DO: Translate
    "playlist-invalid-index-error": "Invalid playlist index", # TO DO: Translate
}
